<?php
/**
 * Class for handle ajax request
 */
if ( ! class_exists( 'IPSocialWidget_Ajax' )) {

    class IPSocialWidget_Ajax
    {
        /**
         * Take ajax action name
         *
         * @var string
         */
        protected $_action;
        
        /**
         * Take ajax action handlers
         *
         * @var array
         */
        protected $_handlers = array(
            
            'ipsw_getsocialicon'   => 'getSocialIcon',
            'ipsw_savewidget'      => 'saveWidget',
            'ipsw_upload'          => 'doAjaxUpload',
            'ipsw_clearimage'      => 'doAjaxClearImage',
            'ipsw_delete'          => 'doAjaxDelete',
        );
        
        /**
         * Class constructor
         *
         * @return void
         */
        public function __construct()
        {
        }
        
        /**
         * Get action name
         *
         * @return string
         */
        public function getAction()
        {
            return $this->_action;
        }
        
        /**
         * Set action
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function setAction( $action )
        {
            $this->_action = sanitize_title( $action );
        }
        
        /**
         * Execute request
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function exec()
        {
            $data = array_merge( $_GET, $_POST );
            if ( empty( $data['doajax'] ) || empty( $data['ipsw'] ) || empty( $data['action'] ) ) {
                return true;
            }
            $this->setAction( $data['action'] );
            
            $action   = $this->getAction();
            $handlers = (array)$this->_handlers;
            if ( array_key_exists( $action, $handlers )) {
                $handler = $handlers[$action];
                if ( method_exists( $this, $handler )) {
                    $this->$handler();
                }
            }
            return true;
        }
        
        /**
         * Menyimpan data opsi widget
         *
         * @return void
         */
        public function saveWidget()
        {
            $result = array();
            if ( ! empty( $_POST['socwidget_id'] )) {
                $widgetId = absint( $_POST['socwidget_id'] );
                $this->_editWidgetData( $widgetId );
            } else {
                $widgetId = $this->_newWidget();
            }
            if ( ! empty( $widgetId )) {
                $setstatus = $this->_saveWidgetSettings( $widgetId );
                if ( isset( $_GET['getpreview'] )) {
                    $result['preview'] = $this->_getPreviewWidget( $widgetId );
                }
                if ( ! empty( $setstatus )) {
                    $status = 1;
                } else {
                    $status = 0;
                }
            } else {
                $status = 0;
            }
            $result['id']     = $widgetId;
            $result['status'] = $status;
            echo json_encode( $result );
            die();
        }
        
        /**
         * Edit widget data
         *
         * @return int
         */
        protected function _editWidgetData( $widgetId )
        {
            $result = 0;
            if ( $widget = get_post( $widgetId )) {
                $toUpdate   = array();
                $typeChange = 0;
                if ( ! empty( $_POST['widget_name'] ) && $_POST['widget_name'] != $widget->post_title ) {
                    $toUpdate['post_title'] = apply_filters( 'single_post_title', $_POST['widget_name'] );
                }
                if ( ! empty( $toUpdate )) {
                    $toUpdate['ID'] = $widget->ID;
                    $result = wp_update_post( $toUpdate );
                }
            }
            return $result;
        }
        
        /**
         * Get Preview Widget
         *
         * @return int
         */
        protected function _getPreviewWidget( $widgetId )
        {
            $preview = '';
            $widget  = get_post( $widgetId );
            $type    = $widget->post_status;
            if ( $type == 'timeline' ) {
                $preview = $this->_getTimelinePreview( $widget );
            } elseif ( $type == 'author' ) {
                $preview = $this->_getAuthorPreview( $widget );
            } elseif ( $type == 'email' ) {
                $preview = $this->_getEmailPreview( $widget );
            } elseif ( $type == 'sales' ) {
                $preview = $this->_getSalesPreview( $widget );
            } elseif ( $type == 'contact' ) {
                $preview = $this->_getContactPreview( $widget );
            } elseif ( $type == 'profile' ) {
                $preview = $this->_getProfilePreview( $widget );
            } elseif ( $type == 'link' ) {
                $preview = $this->_getLinkPreview( $widget );
            }
            return $preview;
        }
        
        /**
         * Get timeline Widget preview
         *
         * @return int
         */
        protected function _getTimelinePreview( $widget )
        {
            $factory = new IPSocialWidget_Factory( $widget->ID );
            return $factory->timelinePreview();
        }
        
        /**
         * Get author Widget preview
         *
         * @return int
         */
        protected function _getAuthorPreview( $widget )
        {
            $factory = new IPSocialWidget_Factory( $widget->ID );
            return $factory->authorPreview();
        }
        
        /**
         * Get email Widget preview
         *
         * @return int
         */
        protected function _getEmailPreview( $widget )
        {
            $factory = new IPSocialWidget_Factory( $widget->ID );
            return $factory->emailPreview();
        }
        
        /**
         * Get sales Widget preview
         *
         * @return int
         */
        protected function _getSalesPreview( $widget )
        {
            $factory = new IPSocialWidget_Factory( $widget->ID );
            return $factory->salesPreview();
        }
        
        /**
         * Get contact Widget preview
         *
         * @return int
         */
        protected function _getContactPreview( $widget )
        {
            $factory = new IPSocialWidget_Factory( $widget->ID );
            return $factory->contactPreview();
        }
        
        /**
         * Get profile Widget preview
         *
         * @return int
         */
        protected function _getProfilePreview( $widget )
        {
            $factory = new IPSocialWidget_Factory( $widget->ID );
            return $factory->profilePreview();
        }
        
        /**
         * Get link Widget preview
         *
         * @return int
         */
        protected function _getLinkPreview( $widget )
        {
            $factory = new IPSocialWidget_Factory( $widget->ID );
            return $factory->linkPreview();
        }
        
        /**
         * Save widget settings
         *
         * @return int
         */
        protected function _saveWidgetSettings( $widgetId )
        {
            $type = sanitize_title( $_POST['widget_type'] );
            if ( $type == 'timeline' ) {
                $toUpdate = $this->_getTimelineSettings();
            } elseif ( $type == 'author' ) {
                $toUpdate = $this->_getAuthorSettings();
            } elseif ( $type == 'email' ) {
                $toUpdate = $this->_getEmailSettings();
            } elseif ( $type == 'sales' ) {
                $toUpdate = $this->_getSalesSettings();
            } elseif ( $type == 'contact' ) {
                $toUpdate = $this->_getContactSettings();
            } elseif ( $type == 'profile' ) {
                $toUpdate = $this->_getProfileSettings();
            } elseif ( $type == 'link' ) {
                $toUpdate = $this->_getLinkSettings();
            }
            $setting = new IPSocialWidget_Setting( $widgetId );
            return $setting->setSettings( $toUpdate );
        }
        
        /**
         * Get widget timeline settings
         *
         * @return int
         */
        protected function _getTimelineSettings()
        {
            $toUpdate = array();
            if ( ! empty( $_POST['ipsw_style'] )) {
                $toUpdate['style'] = apply_filters( 'single_post_title', $_POST['ipsw_style'] );
            }
            if ( ! empty( $_POST['ipsw_ffamily'] )) {
                $toUpdate['font_family'] = apply_filters( 'single_post_title', $_POST['ipsw_ffamily'] );
            }
            if ( ! empty( $_POST['title'] )) {
                $toUpdate['title'] = apply_filters( 'single_post_title', $_POST['title'] );
            }
            if ( ! empty( $_POST['title_color'] )) {
                $toUpdate['title_color'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $_POST['title_color'] );
            }
            if ( ! empty( $_POST['description'] )) {
                $toUpdate['description'] = apply_filters( 'pre_term_description', $_POST['description'] );
            }
            if ( ! empty( $_POST['description_color'] )) {
                $toUpdate['description_color'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $_POST['description_color'] );
            }
            if ( ! empty( $_POST['bgimageid'] )) {
                $toUpdate['bgimageid'] = absint( $_POST['bgimageid'] );
            }
            if ( ! empty( $_POST['photoid'] )) {
                $toUpdate['photoid'] = absint( $_POST['photoid'] );
            }
            if ( ! empty( $_POST['footer_text'] )) {
                $toUpdate['footer_text'] = apply_filters( 'single_post_title', $_POST['footer_text'] );
            }
            if ( ! empty( $_POST['footer_text_color'] )) {
                $toUpdate['footer_text_color'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $_POST['footer_text_color'] );
            }
            $socialLinks = $this->_getSocialLinkSettings();
            $toUpdate    = array_merge( $toUpdate, $socialLinks );
            
            return $toUpdate;
        }
        
        /**
         * Get widget author settings
         *
         * @return int
         */
        protected function _getAuthorSettings()
        {
            $toUpdate = $this->_getTimelineSettings();
            return $toUpdate;
        }
        
        /**
         * Get widget email settings
         *
         * @return int
         */
        protected function _getEmailSettings()
        {
            $toUpdate = array();
            if ( ! empty( $_POST['ipsw_style'] )) {
                $toUpdate['style'] = apply_filters( 'single_post_title', $_POST['ipsw_style'] );
            }
            if ( ! empty( $_POST['ipsw_ffamily'] )) {
                $toUpdate['font_family'] = apply_filters( 'single_post_title', $_POST['ipsw_ffamily'] );
            }
            if ( ! empty( $_POST['title'] )) {
                $toUpdate['title'] = apply_filters( 'single_post_title', $_POST['title'] );
            }
            if ( ! empty( $_POST['title_color'] )) {
                $toUpdate['title_color'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $_POST['title_color'] );
            }
            if ( ! empty( $_POST['description'] )) {
                $toUpdate['description'] = apply_filters( 'pre_term_description', $_POST['description'] );
            }
            if ( ! empty( $_POST['description_color'] )) {
                $toUpdate['description_color'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $_POST['description_color'] );
            }
            if ( ! empty( $_POST['email'] )) {
                $toUpdate['email'] = sanitize_email( $_POST['email'] );
            }
            if ( ! empty( $_POST['label'] )) {
                $toUpdate['label'] = apply_filters( 'single_post_title', $_POST['label'] );
            }
            if ( ! empty( $_POST['label_color'] )) {
                $toUpdate['label_color'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $_POST['label_color'] );
            }
            if ( ! empty( $_POST['photoid'] )) {
                $toUpdate['photoid'] = absint( $_POST['photoid'] );
            }
            $socialLinks = $this->_getSocialLinkSettings();
            $toUpdate    = array_merge( $toUpdate, $socialLinks );
            
            return $toUpdate;
        }
        
        /**
         * Get widget sales settings
         *
         * @return int
         */
        protected function _getSalesSettings()
        {
            $toUpdate = array();
            if ( ! empty( $_POST['ipsw_style'] )) {
                $toUpdate['style'] = apply_filters( 'single_post_title', $_POST['ipsw_style'] );
            }
            if ( ! empty( $_POST['ipsw_ffamily'] )) {
                $toUpdate['font_family'] = apply_filters( 'single_post_title', $_POST['ipsw_ffamily'] );
            }
            if ( ! empty( $_POST['title'] )) {
                $toUpdate['title'] = apply_filters( 'single_post_title', $_POST['title'] );
            }
            if ( ! empty( $_POST['title_color'] )) {
                $toUpdate['title_color'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $_POST['title_color'] );
            }
            if ( ! empty( $_POST['description'] )) {
                $toUpdate['description'] = apply_filters( 'pre_term_description', $_POST['description'] );
            }
            if ( ! empty( $_POST['description_color'] )) {
                $toUpdate['description_color'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $_POST['description_color'] );
            }
            if ( ! empty( $_POST['price'] )) {
                $toUpdate['price'] = apply_filters( 'single_post_title', $_POST['price'] );
            }
            if ( ! empty( $_POST['label'] )) {
                $toUpdate['label'] = apply_filters( 'single_post_title', $_POST['label'] );
            }
            if ( ! empty( $_POST['url'] )) {
                $toUpdate['url'] = apply_filters( 'pre_link_url', $_POST['url'] );
            }
            if ( ! empty( $_POST['bgimageid'] )) {
                $toUpdate['bgimageid'] = absint( $_POST['bgimageid'] );
            }
            if ( ! empty( $_POST['photoid'] )) {
                $toUpdate['photoid'] = absint( $_POST['photoid'] );
            }
            if ( ! empty( $_POST['footer_text'] )) {
                $toUpdate['footer_text'] = apply_filters( 'single_post_title', $_POST['footer_text'] );
            }
            if ( ! empty( $_POST['footer_text_color'] )) {
                $toUpdate['footer_text_color'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $_POST['footer_text_color'] );
            }
            $socialLinks = $this->_getSocialLinkSettings();
            $toUpdate    = array_merge( $toUpdate, $socialLinks );
            
            return $toUpdate;
        }
        
        /**
         * Get widget contact settings
         *
         * @return int
         */
        protected function _getContactSettings()
        {
            $toUpdate = array();
            if ( ! empty( $_POST['ipsw_style'] )) {
                $toUpdate['style'] = apply_filters( 'single_post_title', $_POST['ipsw_style'] );
            }
            if ( ! empty( $_POST['ipsw_ffamily'] )) {
                $toUpdate['font_family'] = apply_filters( 'single_post_title', $_POST['ipsw_ffamily'] );
            }
            if ( ! empty( $_POST['name'] )) {
                $toUpdate['name'] = apply_filters( 'single_post_title', $_POST['name'] );
            }
            if ( ! empty( $_POST['name_color'] )) {
                $toUpdate['name_color'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $_POST['name_color'] );
            }
            if ( ! empty( $_POST['address'] )) {
                $toUpdate['address'] = apply_filters( 'pre_term_description', $_POST['address'] );
            }
            if ( ! empty( $_POST['email'] )) {
                $toUpdate['email'] = sanitize_email( $_POST['email'] );
            }
            if ( ! empty( $_POST['phone'] )) {
                $toUpdate['phone'] = apply_filters( 'single_post_title', $_POST['phone'] );
            }
            if ( ! empty( $_POST['mobile'] )) {
                $toUpdate['mobile'] = apply_filters( 'single_post_title', $_POST['mobile'] );
            }
            if ( ! empty( $_POST['fax'] )) {
                $toUpdate['fax'] = apply_filters( 'single_post_title', $_POST['fax'] );
            }
            if ( ! empty( $_POST['color'] )) {
                $toUpdate['color'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $_POST['color'] );
            }
            if ( ! empty( $_POST['photoid'] )) {
                $toUpdate['photoid'] = absint( $_POST['photoid'] );
            }
            $socialLinks = $this->_getSocialLinkSettings();
            $toUpdate    = array_merge( $toUpdate, $socialLinks );
            
            return $toUpdate;
        }
        
        /**
         * Get widget profile settings
         *
         * @return int
         */
        protected function _getProfileSettings()
        {
            $toUpdate = array();
            if ( ! empty( $_POST['ipsw_style'] )) {
                $toUpdate['style'] = apply_filters( 'single_post_title', $_POST['ipsw_style'] );
            }
            if ( ! empty( $_POST['ipsw_ffamily'] )) {
                $toUpdate['font_family'] = apply_filters( 'single_post_title', $_POST['ipsw_ffamily'] );
            }
            if ( ! empty( $_POST['title'] )) {
                $toUpdate['title'] = apply_filters( 'single_post_title', $_POST['title'] );
            }
            if ( ! empty( $_POST['title_color'] )) {
                $toUpdate['title_color'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $_POST['title_color'] );
            }
            if ( ! empty( $_POST['description'] )) {
                $toUpdate['description'] = apply_filters( 'pre_term_description', $_POST['description'] );
            }
            if ( ! empty( $_POST['description_color'] )) {
                $toUpdate['description_color'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $_POST['description_color'] );
            }
            if ( ! empty( $_POST['permalink'] )) {
                $toUpdate['permalink'] = apply_filters( 'pre_link_url', $_POST['permalink'] );
            }
            if ( ! empty( $_POST['label'] )) {
                $toUpdate['label'] = apply_filters( 'single_post_title', $_POST['label'] );
            }
            if ( ! empty( $_POST['label_color'] )) {
                $toUpdate['label_color'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $_POST['label_color'] );
            }
            if ( ! empty( $_POST['bgimageid'] )) {
                $toUpdate['bgimageid'] = absint( $_POST['bgimageid'] );
            }
            if ( ! empty( $_POST['photoid'] )) {
                $toUpdate['photoid'] = absint( $_POST['photoid'] );
            }
            $socialLinks = $this->_getSocialLinkSettings();
            $toUpdate    = array_merge( $toUpdate, $socialLinks );
            
            return $toUpdate;
        }
        
        /**
         * Get widget link settings
         *
         * @return int
         */
        protected function _getLinkSettings()
        {
            $toUpdate = array();
            if ( ! empty( $_POST['ipsw_style'] )) {
                $toUpdate['style'] = apply_filters( 'single_post_title', $_POST['ipsw_style'] );
            }
            if ( ! empty( $_POST['ipsw_ffamily'] )) {
                $toUpdate['font_family'] = apply_filters( 'single_post_title', $_POST['ipsw_ffamily'] );
            }
            if ( ! empty( $_POST['title'] )) {
                $toUpdate['title'] = apply_filters( 'single_post_title', $_POST['title'] );
            }
            if ( ! empty( $_POST['title_color'] )) {
                $toUpdate['title_color'] = preg_replace( '@[^a-zA-Z0-9\#]@', '', $_POST['title_color'] );
            }
            $socialLinks = $this->_getSocialLinkSettings();
            $toUpdate    = array_merge( $toUpdate, $socialLinks );
            
            return $toUpdate;
        }
        
        /**
         * Get social links settings
         *
         * @return int
         */
        protected function _getSocialLinkSettings()
        {
            $links = array();
            if ( ! empty( $_POST['social_type'] )) {
                foreach( $_POST['social_type'] as $idx => $value ) {
                    $type = sanitize_title( $value );
                    $icon = '';
                    if ( ! empty( $_POST['social_icon'][$idx] )) {
                        $icon = $_POST['social_icon'][$idx];
                    }
                    $url = '';
                    if ( ! empty( $_POST['social_link'][$idx] )) {
                        $url = sanitize_title( $_POST['social_link'][$idx] );
                    }
                    $links[] = array(
                        'type' => $type,
                        'icon' => $icon,
                        'url'  => $url
                    );
                }
            }
            return array( 'social_links' => $links );
        }
        
        /**
         * Add new widget
         *
         * @return int
         */
        protected function _newWidget()
        {
            global $user_ID;
            
            if ( empty( $_POST['widget_name'] )) {
                $title = 'Unknown';
            } else {
                $title = apply_filters( 'single_post_title', $_POST['widget_name'] );
            }
            $type = sanitize_title( $_REQUEST['widget_type'] );
            $dataPost = array(
                'post_status' => $type,
                'post_type'   => 'ipsocialwidget', 
                'post_author' => $user_ID,
                'post_title'  => $title
            );
            $result = wp_insert_post( $dataPost );
            return $result;
        }
        
        /**
         * Processing ajax for delete widget
         *
         * @return void
         */
        public function doAjaxDelete()
        {
            $widget = false;
            if ( ! empty( $_REQUEST['widget_id'] )) {
                $id     = absint( $_REQUEST['widget_id'] );
                $widget = get_post( $id );
            }
            if ( ! $widget ) {
                echo json_encode( array(
                    'status'  => 0,
                    'data'    => array(
                        'message'  => __( 'Error system' )
                    )
                ) );
                die();
            }
            $result = wp_delete_post( $widget->ID, true );
            if ( $result ) {
                echo json_encode( array(
                    'status'  => 1,
                    'data'    => array(
                        'message'  => __( 'Successfully remove the widget' )
                    )
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'data'    => array(
                        'message'  => __( 'Failed to remove the widget' )
                    )
                ) );
            }
            die();
        }
        
        /**
         * Processing ajax for upload image
         *
         * @return void
         */
        public function doAjaxUpload()
        {
            if ( ! empty( $_REQUEST['widget_id'] )) {
                $widgetid = absint( $_REQUEST['widget_id'] );
            } else {
                $widgetid = $this->_newWidget();
            }
            if ( ! $widgetid ) {
                echo json_encode( array(
                    'status'  => 0,
                    'data'    => array(
                        'message'  => __( 'Error system' )
                    )
                ) );
                die();
            }
            if ( ! empty( $_FILES['async-upload'] )) {
            
                $filetype = wp_check_filetype_and_ext( $_FILES['async-upload']['tmp_name'], $_FILES['async-upload']['name'], false );
                if ( ! wp_match_mime_types( 'image', $filetype['type'] ) ) {
                    echo json_encode( array(
                        'status'  => 0,
                        'data'    => array(
                            'message'  => __( 'The uploaded file is not a valid image. Please try again.' ),
                            'filename' => $_FILES['async-upload']['name'],
                        )
                    ) );
                    die();
                }
                $attachment_id = media_handle_upload( 'async-upload', $widgetid, array() );
                if ( is_wp_error( $attachment_id ) ) {
                    echo json_encode( array(
                        'status' => 0,
                        'data'    => array(
                            'message'  => $attachment_id->get_error_message(),
                            'filename' => $_FILES['async-upload']['name'],
                        )
                    ) );
                    die();
                }
                if ( ! $attachment = wp_prepare_attachment_for_js( $attachment_id ) ) {
                    die();
                }
                
                //Update settings
                if ( ! empty( $_REQUEST['type'] )) {
                    $type = preg_replace( '@[^a-zA-Z0-9\_\-]@', '', $_REQUEST['type'] );
                    $updater = new IPSocialWidget_Setting( $widgetid );
                    $updater->setSetting( $type, $attachment_id );
                }
                
                echo json_encode( array(
                    'status'   => 1,
                    'data'     => $attachment,
                    'widgetid' => $widgetid
                ));
            }
            die();
        }
        
        /**
         * Processing ajax for clearing image
         *
         * @return void
         */
        public function doAjaxClearImage()
        {
            $widget = $attach = false;
            if ( ! empty( $_REQUEST['widget_id'] )) {
                $id    = absint( $_REQUEST['widget_id'] );
                $widget = get_post( $id );
            }
            if ( ! empty( $_REQUEST['attach'] )) {
                $attachid = absint( $_REQUEST['attach'] );
                $attach   = get_post( $attachid );
            }
            if ( ! $widget || ! $attach ) {
                echo json_encode( array(
                    'status'  => 0,
                    'data'    => array(
                        'message'  => __( 'Error system' )
                    )
                ) );
                die();
            }
            
            $delete = wp_delete_attachment( $attachid, true );
            if ( $delete ) {
                //Update settings
                if ( ! empty( $_REQUEST['type'] )) {
                    $type    = preg_replace( '@[^a-zA-Z0-9\_\-]@', '', $_REQUEST['type'] );
                    $updater = new IPPopup_Setting( $widget->ID );
                    $updater->setSetting( $type, 0 );
                }
                echo json_encode( array(
                    'status' => 1,
                    'data'   => array(
                        'message'  => __( 'Successfully clearing image' )
                    )
                ));
            
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'data'    => array(
                        'message'  => __( 'Error clearing image' )
                    )
                ) );
            }
            die();
        }
        
        /**
         * Get icon social options
         *
         * @return void
         */
        public function getSocialIcon()
        {
            $data = array_merge( $_GET, $_POST );
            if ( ! empty( $data['name'] )) {
                $name   = trim( $data['name'] );
                $plgurl = plugin_dir_url( dirname(__FILE__) );
                $imgurl = $plgurl . 'img/social/';
                $file   = strtolower( $name ) . '.png';
                ?>
                
                <div class="ipsw-menu ipsw-gen-menu">
                    <div class="ipsw-selected">
                        <div class="ipsw-selected-box">
                            <img src="<?php echo $imgurl . 'style1/' . $file; ?>" alt="Style 1" />
                        </div>
                        <span class="toggle"></span>
                    </div>
                    <div class="ipsw-select" style="display: none;">
                        <div class="ipsw-select-content">
                            <ul class="clearfix">
                                <li data-select="style1">
                                    <strong class="ipsw-select-label">
                                        <img src="<?php echo $imgurl . 'style1/' . $file; ?>" alt="Style 1" />
                                    </strong>
                                </li>
                                <li data-select="style2">
                                    <strong class="ipsw-select-label">
                                        <img src="<?php echo $imgurl . 'style2/' . $file; ?>" alt="Style 2" />
                                    </strong>
                                </li>
                                <li data-select="style3">
                                    <strong class="ipsw-select-label">
                                        <img src="<?php echo $imgurl . 'style3/' . $file; ?>" alt="Style 3" />
                                    </strong>
                                </li>
                                <li data-select="style4">
                                    <strong class="ipsw-select-label">
                                        <img src="<?php echo $imgurl . 'style4/' . $file; ?>" alt="Style 4" />
                                    </strong>
                                </li>
                                <li data-select="style5">
                                    <strong class="ipsw-select-label">
                                        <img src="<?php echo $imgurl . 'style5/' . $file; ?>" alt="Style 5" />
                                    </strong>
                                </li>
                                <li data-select="style6">
                                    <strong class="ipsw-select-label">
                                        <img src="<?php echo $imgurl . 'style6/' . $file; ?>" alt="Style 6" />
                                    </strong>
                                </li>
                                <li data-select="style7">
                                    <strong class="ipsw-select-label">
                                        <img src="<?php echo $imgurl . 'style7/' . $file; ?>" alt="Style 7" />
                                    </strong>
                                </li>
                            </ul>
                        </div>
                    </div>
                    <input type="hidden" name="social_icon[]" class="ipsw-input-select" value="style1" />
                </div>
            <?php
            }
            die();
        }
    }
    
}
?>