<?php
/**
 * Class for build cwidget
 */
if ( ! class_exists( 'IPSocialWidget_Factory' )) {

    class IPSocialWidget_Factory
    {
        /**
         * Take widget id
         *
         * @var int
         */
        protected $_widgetId;
        
        /**
         * Take widget
         *
         * @var object
         */
        protected $_widget;
        
        /** 
         * Class constructor
         *
         * @param  int|object $widget
         * @return void
         */
        public function __construct( $widget )
        {
            if ( is_int( $widget )) {
                $this->_widgetId = absint( $widget );
                $this->_widget   = get_post( $this->_widgetId );
            } elseif ( is_object( $widget )) {
                $this->_widget   = $widget;
                $this->_widgetId = $widget->ID;
            }
        }
        
        /**
         * Create timeline widget preview
         *
         * @return string
         */
        public function timelinePreview()
        {
            $preview = '
            <h3>Post Content</h3>
            <div class="preview-item preview-post">
                ' . $this->timelinePost() .'
            </div>
            <h3>Widget</h3>
            <div class="preview-item preview-widget">
                ' . $this->timelineWidget() .'
            </div>
            <h3>Page Popup</h3>
            <div class="preview-item preview-popup">
                ' . $this->timelinePopup() .'
            </div>';
            
            return $preview;
        }
        
        /**
         * Create timeline post content
         *
         * @return string
         */
        public function timelinePost()
        {
            if ( ! $this->_widget ) {
                return '';
            }
            $setting    = new IPSocialWidget_Setting( $this->_widgetId );
            $style      = $setting->getSetting( 'style', 'style1' );
            $bgimage    = $setting->getSetting( 'background_image' );
            $photo      = $setting->getSetting( 'photo_profile' );
            $title      = $setting->getSetting( 'title' );
            $clr_title  = $setting->getSetting( 'title_color' );
            $desc       = $setting->getSetting( 'description' );
            $clr_desc   = $setting->getSetting( 'description_color' );
            $footer     = $setting->getSetting( 'footer_text' );
            $clr_footer = $setting->getSetting( 'footer_text_color' );
            $links      = $setting->getSetting( 'social_links' );
            $font       = $setting->getSetting( 'font_family', 'Arial' );
            $font       = str_replace( '_', ' ', $font );
            
            $result  = '<div class="ipsw-item ipsw-timeline ipsw-post ipsw-' . $style . '">
                            <div class="ipsw-inner" style="font-family: ' . "'$font'" . ';">';
            
            if ( ! empty( $bgimage )) {
                $image   = get_post( $bgimage );
                $bgimage = '';
                if ( ! empty( $image->guid )) {
                    $bgimage = ' style="background: url( ' . "'{$image->guid}'" . ' ) repeat;"';
                }
            }
            $result .= '<div class="ipsw-content clearfix"' . $bgimage . '>
                          <div class="ipsw-content-main">
                            <h2 style="color: ' . $clr_title . '; font-family: ' . "'$font'" . ';">' . $title . '</h2>
                            <p style="color: ' . $clr_desc . ';">' . $desc . '</p>
                          </div>';
            
            if ( ! empty( $photo )) {
                $image = get_post( $photo );
                $result .= '<div class="ipsw-photo">
                                <img src="' . $image->guid . '" alt="" />
                            </div>';
            }
            
            $result .= '</div>';
            
            $result .= '<div class="ipsw-footer clearfix">
                            <div class="ipsw-info">
                                <em style="color: ' . $clr_footer . ';">' . $footer . '</em>
                            </div>';
            
            if ( ! empty( $links )) {
                $result .= '<div class="ipsw-social">
                                <ul>';
                
                foreach( $links as $link ) {
                    $url = $this->_getSocialHost( $link['type'] ) . $link['url'];
                    $src = plugin_dir_url( dirname(__FILE__) ) . 'img/social/' 
                            . $link['icon'] . '/' . $link['type'] . '.png';
                    $result .= '<li><a href="' . $url . '">
                                    <img src="' . $src . '" alt="' . $link['type'] . '">
                                </a></li>';
                }
                
                $result .= '    </ul>
                            </div>';
            }
            $result .= '</div>';
            
            $result .= '    </div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Create timeline widget content
         *
         * @return string
         */
        public function timelineWidget()
        {
            if ( ! $this->_widget ) {
                return '';
            }
            $setting    = new IPSocialWidget_Setting( $this->_widgetId );
            $style      = $setting->getSetting( 'style', 'style1' );
            $bgimage    = $setting->getSetting( 'background_image' );
            $photo      = $setting->getSetting( 'photo_profile' );
            $title      = $setting->getSetting( 'title' );
            $clr_title  = $setting->getSetting( 'title_color' );
            $desc       = $setting->getSetting( 'description' );
            $clr_desc   = $setting->getSetting( 'description_color' );
            $footer     = $setting->getSetting( 'footer_text' );
            $clr_footer = $setting->getSetting( 'footer_text_color' );
            $links      = $setting->getSetting( 'social_links' );
            $font       = $setting->getSetting( 'font_family', 'Arial' );
            $font       = str_replace( '_', ' ', $font );
            
            $result  = '<div class="ipsw-item ipsw-timeline ipsw-widget ipsw-' . $style . '">
                            <div class="ipsw-inner" style="font-family: ' . "'$font'" . ';">';
            
            if ( ! empty( $bgimage )) {
                $image   = get_post( $bgimage );
                $bgimage = '';
                if ( ! empty( $image->guid )) {
                    $bgimage = ' style="background: url( ' . "'{$image->guid}'" . ' ) repeat;"';
                }
            }
            $result .= '<div class="ipsw-content clearfix"' . $bgimage . '>
                          <h2 class="ipsw-title" style="color: ' . $clr_title . '; font-family: ' . "'$font'" . ';">' . $title . '</h2>';
            if ( $style != 'style3' ) {
                $result .= '<p class="ipsw-desc" style="color: ' . $clr_desc . ';">' . $desc . '</p>';
            }
            if ( ! empty( $photo )) {
                $image = get_post( $photo );
                $result .= '<div class="ipsw-photo">
                                <img src="' . $image->guid . '" alt="" />
                            </div>';
            }
            if ( $style == 'style3' ) {
                $result .= '<p class="ipsw-desc" style="color: ' . $clr_desc . ';">' . $desc . '</p>';
            }
            $result .= '</div>';
            
            $result .= '<div class="ipsw-footer clearfix">
                            <div class="ipsw-info">
                                <em style="color: ' . $clr_footer . ';">' . $footer . '</em>
                            </div>';
            
            if ( ! empty( $links )) {
                $result .= '<div class="ipsw-social">
                                <ul>';
                
                foreach( $links as $link ) {
                    $url = $this->_getSocialHost( $link['type'] ) . $link['url'];
                    $src = plugin_dir_url( dirname(__FILE__) ) . 'img/social/' 
                            . $link['icon'] . '/' . $link['type'] . '.png';
                    $result .= '<li><a href="' . $url . '">
                                    <img src="' . $src . '" alt="' . $link['type'] . '">
                                </a></li>';
                }
                
                $result .= '    </ul>
                            </div>';
            }
            $result .= '</div>';
            
            $result .= '    </div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Create timeline popup content
         *
         * @return string
         */
        public function timelinePopup()
        {
            if ( ! $this->_widget ) {
                return '';
            }
            $setting    = new IPSocialWidget_Setting( $this->_widgetId );
            $style      = $setting->getSetting( 'style', 'style1' );
            $bgimage    = $setting->getSetting( 'background_image' );
            $photo      = $setting->getSetting( 'photo_profile' );
            $title      = $setting->getSetting( 'title' );
            $clr_title  = $setting->getSetting( 'title_color' );
            $desc       = $setting->getSetting( 'description' );
            $clr_desc   = $setting->getSetting( 'description_color' );
            $footer     = $setting->getSetting( 'footer_text' );
            $clr_footer = $setting->getSetting( 'footer_text_color' );
            $links      = $setting->getSetting( 'social_links' );
            $font       = $setting->getSetting( 'font_family', 'Arial' );
            $font       = str_replace( '_', ' ', $font );
            
            $result  = '<div class="ipsw-item ipsw-timeline ipsw-popup ipsw-' . $style . '">
                            <div class="ipsw-inner" style="font-family: ' . "'$font'" . ';">';
            
            if ( ! empty( $bgimage )) {
                $image   = get_post( $bgimage );
                $bgimage = '';
                if ( ! empty( $image->guid )) {
                    $bgimage = ' style="background: url( ' . "'{$image->guid}'" . ' ) repeat;"';
                }
            }
            $result .= '<div class="ipsw-content clearfix"' . $bgimage . '>
                          <div class="ipsw-content-main">
                            <h2 style="color: ' . $clr_title . '; font-family: ' . "'$font'" . ';">' . $title . '</h2>
                            <p style="color: ' . $clr_desc . ';">' . $desc . '</p>
                          </div>';
            
            if ( ! empty( $photo )) {
                $image = get_post( $photo );
                $result .= '<div class="ipsw-photo">
                                <img src="' . $image->guid . '" alt="" />
                            </div>';
            }
            
            $result .= '</div>';
            
            $result .= '<div class="ipsw-footer clearfix">
                            <div class="ipsw-info">
                                <em style="color: ' . $clr_footer . ';">' . $footer . '</em>
                            </div>';
            
            if ( ! empty( $links )) {
                $result .= '<div class="ipsw-social">
                                <ul>';
                
                foreach( $links as $link ) {
                    $url = $this->_getSocialHost( $link['type'] ) . $link['url'];
                    $src = plugin_dir_url( dirname(__FILE__) ) . 'img/social/' 
                            . $link['icon'] . '/' . $link['type'] . '.png';
                    $result .= '<li><a href="' . $url . '">
                                    <img src="' . $src . '" alt="' . $link['type'] . '">
                                </a></li>';
                }
                
                $result .= '    </ul>
                            </div>';
            }
            $result .= '</div>
                        <div class="ipsw-widget-popup-close">
                            <a href="">x</a>
                        </div>';
            
            $result .= '    </div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Create author widget preview
         *
         * @return string
         */
        public function authorPreview()
        {
            $preview = '
            <h3>Post Content</h3>
            <div class="preview-item preview-post">
                ' . $this->authorPost() .'
            </div>
            <h3>Widget</h3>
            <div class="preview-item preview-widget">
                ' . $this->authorWidget() .'
            </div>
            <h3>Page Popup</h3>
            <div class="preview-item preview-popup">
                ' . $this->authorPopup() .'
            </div>';
            
            return $preview;
        }
        
        /**
         * Create author post content
         *
         * @return string
         */
        public function authorPost()
        {
            if ( ! $this->_widget ) {
                return '';
            }
            $setting    = new IPSocialWidget_Setting( $this->_widgetId );
            $style      = $setting->getSetting( 'style', 'style1' );
            $bgimage    = $setting->getSetting( 'background_image' );
            $photo      = $setting->getSetting( 'photo_profile' );
            $title      = $setting->getSetting( 'title' );
            $clr_title  = $setting->getSetting( 'title_color' );
            $desc       = $setting->getSetting( 'description' );
            $clr_desc   = $setting->getSetting( 'description_color' );
            $footer     = $setting->getSetting( 'footer_text' );
            $clr_footer = $setting->getSetting( 'footer_text_color' );
            $links      = $setting->getSetting( 'social_links' );
            $font       = $setting->getSetting( 'font_family', 'Arial' );
            $font       = str_replace( '_', ' ', $font );
            
            $html_title = '<h2 class="ipsw-title" style="color: ' . $clr_title . '; font-family: ' . "'$font'" . ';">' . $title . '</h2>';
            $html_desc  = '<p class="ipsw-desc" style="color: ' . $clr_desc . ';">' . $desc . '</p>';
            $html_photo = '';
            if ( ! empty( $photo )) {
                $image      = get_post( $photo );
                $html_photo = '<div class="ipsw-photo">
                                    <img src="' . $image->guid . '" alt="" />
                               </div>';
            }
            $html_info =   '<div class="ipsw-info">
                                <em style="color: ' . $clr_footer . ';">' . $footer . '</em>
                            </div>';
            $html_soc  = '';
            if ( ! empty( $links )) {
                $html_soc = '<div class="ipsw-social">
                                <ul>';
                
                foreach( $links as $link ) {
                    $url = $this->_getSocialHost( $link['type'] ) . $link['url'];
                    $src = plugin_dir_url( dirname(__FILE__) ) . 'img/social/' 
                            . $link['icon'] . '/' . $link['type'] . '.png';
                    $html_soc .= '<li><a href="' . $url . '">
                                    <img src="' . $src . '" alt="' . $link['type'] . '">
                                </a></li>';
                }
                
                $html_soc .= '    </ul>
                            </div>';
            }
            
            $result  = '<div class="ipsw-item ipsw-author ipsw-post ipsw-' . $style . '">
                            <div class="ipsw-inner clearfix" style="font-family: ' . "'$font'" . ';">';
            
            if ( ! empty( $bgimage )) {
                $image   = get_post( $bgimage );
                $bgimage = '';
                if ( ! empty( $image->guid )) {
                    $bgimage = ' style="background: url( ' . "'{$image->guid}'" . ' ) repeat;"';
                }
            }
            
            $result .= '<div class="ipsw-content clearfix"' . $bgimage . '>';
            if ( $style == 'style1' ) {
                $result .= $html_title;
                $result .= '<div class="ipsw-content-main clearfix">';
                $result .= $html_desc;
                $result .= $html_photo;
                $result .= '</div>';
            
            } elseif ( $style == 'style2' ) {
                $result .= '<div class="ipsw-content-main">';
                $result .= $html_title;
                $result .= $html_desc;
                $result .= '</div>';
                $result .= $html_photo;
                
            } elseif ( $style == 'style3' ) {
                $result .= '<div class="ipsw-content-sec">';
                $result .= $html_photo;
                $result .= $html_soc;
                $result .= '</div>';
            }
            $result .= '</div>';
            
            $result .= '<div class="ipsw-footer clearfix">';
            if ( $style == 'style1' || $style == 'style2' ) {
                $result .= $html_info;
                $result .= $html_soc;
            
            } elseif ( $style == 'style3' ) {
                $result .= '<div class="ipsw-content-main">';
                $result .= $html_title;
                $result .= $html_desc;
                $result .= $html_info;
                $result .= '</div>';
            }
            $result .= '</div>';
            
            $result .= '    </div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Create author widget content
         *
         * @return string
         */
        public function authorWidget()
        {
            if ( ! $this->_widget ) {
                return '';
            }
            $setting    = new IPSocialWidget_Setting( $this->_widgetId );
            $style      = $setting->getSetting( 'style', 'style1' );
            $bgimage    = $setting->getSetting( 'background_image' );
            $photo      = $setting->getSetting( 'photo_profile' );
            $title      = $setting->getSetting( 'title' );
            $clr_title  = $setting->getSetting( 'title_color' );
            $desc       = $setting->getSetting( 'description' );
            $clr_desc   = $setting->getSetting( 'description_color' );
            $footer     = $setting->getSetting( 'footer_text' );
            $clr_footer = $setting->getSetting( 'footer_text_color' );
            $links      = $setting->getSetting( 'social_links' );
            $font       = $setting->getSetting( 'font_family', 'Arial' );
            $font       = str_replace( '_', ' ', $font );
            
            $html_title = '<h2 class="ipsw-title" style="color: ' . $clr_title . '; font-family: ' . "'$font'" . ';">' . $title . '</h2>';
            $html_desc  = '<p class="ipsw-desc" style="color: ' . $clr_desc . ';">' . $desc . '</p>';
            $html_photo = '';
            if ( ! empty( $photo )) {
                $image      = get_post( $photo );
                $html_photo = '<div class="ipsw-photo">
                                    <img src="' . $image->guid . '" alt="" />
                               </div>';
            }
            $html_info =   '<div class="ipsw-info">
                                <em style="color: ' . $clr_footer . ';">' . $footer . '</em>
                            </div>';
            $html_soc  = '';
            if ( ! empty( $links )) {
                $html_soc = '<div class="ipsw-social">
                                <ul>';
                
                foreach( $links as $link ) {
                    $url = $this->_getSocialHost( $link['type'] ) . $link['url'];
                    $src = plugin_dir_url( dirname(__FILE__) ) . 'img/social/' 
                            . $link['icon'] . '/' . $link['type'] . '.png';
                    $html_soc .= '<li><a href="' . $url . '">
                                    <img src="' . $src . '" alt="' . $link['type'] . '">
                                </a></li>';
                }
                
                $html_soc .= '    </ul>
                            </div>';
            }
            
            $result  = '<div class="ipsw-item ipsw-author ipsw-widget ipsw-' . $style . '">
                            <div class="ipsw-inner clearfix" style="font-family: ' . "'$font'" . ';">';
            
            if ( ! empty( $bgimage )) {
                $image   = get_post( $bgimage );
                $bgimage = '';
                if ( ! empty( $image->guid )) {
                    $bgimage = ' style="background: url( ' . "'{$image->guid}'" . ' ) repeat;"';
                }
            }
            
            $result .= '<div class="ipsw-content clearfix"' . $bgimage . '>';
            if ( $style == 'style1' ) {
                $result .= '<div class="ipsw-content-main clearfix">';
                $result .= $html_title;
                $result .= $html_desc;
                $result .= $html_photo;
                $result .= '</div>';
            
            } elseif ( $style == 'style2' ) {
                $result .= '<div class="ipsw-content-main">';
                $result .= $html_title;
                $result .= $html_photo;
                $result .= $html_desc;
                $result .= '</div>';
                
            } elseif ( $style == 'style3' ) {
                $result .= '<div class="ipsw-content-sec clearfix">';
                $result .= $html_photo;
                $result .= $html_info;
                $result .= '</div>';
            }
            $result .= '</div>';
            
            $result .= '<div class="ipsw-footer clearfix">';
            if ( $style == 'style1' ) {
                $result .= $html_soc;
                $result .= $html_info;
            
            } elseif ( $style == 'style2' ) {
                $result .= $html_info;
                $result .= $html_soc;
            
            } elseif ( $style == 'style3' ) {
                $result .= '<div class="ipsw-content-main">';
                $result .= $html_title;
                $result .= $html_desc;
                $result .= $html_soc;
                $result .= '</div>';
            }
            $result .= '</div>';
            
            $result .= '    </div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Create author popup content
         *
         * @return string
         */
        public function authorPopup()
        {
            if ( ! $this->_widget ) {
                return '';
            }
            $setting    = new IPSocialWidget_Setting( $this->_widgetId );
            $style      = $setting->getSetting( 'style', 'style1' );
            $bgimage    = $setting->getSetting( 'background_image' );
            $photo      = $setting->getSetting( 'photo_profile' );
            $title      = $setting->getSetting( 'title' );
            $clr_title  = $setting->getSetting( 'title_color' );
            $desc       = $setting->getSetting( 'description' );
            $clr_desc   = $setting->getSetting( 'description_color' );
            $footer     = $setting->getSetting( 'footer_text' );
            $clr_footer = $setting->getSetting( 'footer_text_color' );
            $links      = $setting->getSetting( 'social_links' );
            $font       = $setting->getSetting( 'font_family', 'Arial' );
            $font       = str_replace( '_', ' ', $font );
            
            $html_title = '<h2 class="ipsw-title" style="color: ' . $clr_title . '; font-family: ' . "'$font'" . ';">' . $title . '</h2>';
            $html_desc  = '<p class="ipsw-desc" style="color: ' . $clr_desc . ';">' . $desc . '</p>';
            $html_photo = '';
            if ( ! empty( $photo )) {
                $image      = get_post( $photo );
                $html_photo = '<div class="ipsw-photo">
                                    <img src="' . $image->guid . '" alt="" />
                               </div>';
            }
            $html_info =   '<div class="ipsw-info">
                                <em style="color: ' . $clr_footer . ';">' . $footer . '</em>
                            </div>';
            $html_soc  = '';
            if ( ! empty( $links )) {
                $html_soc = '<div class="ipsw-social">
                                <ul>';
                
                foreach( $links as $link ) {
                    $url = $this->_getSocialHost( $link['type'] ) . $link['url'];
                    $src = plugin_dir_url( dirname(__FILE__) ) . 'img/social/' 
                            . $link['icon'] . '/' . $link['type'] . '.png';
                    $html_soc .= '<li><a href="' . $url . '">
                                    <img src="' . $src . '" alt="' . $link['type'] . '">
                                </a></li>';
                }
                
                $html_soc .= '    </ul>
                            </div>';
            }
            
            $result  = '<div class="ipsw-item ipsw-author ipsw-popup ipsw-' . $style . '">
                            <div class="ipsw-inner clearfix" style="font-family: ' . "'$font'" . ';">';
            
            if ( ! empty( $bgimage )) {
                $image   = get_post( $bgimage );
                $bgimage = '';
                if ( ! empty( $image->guid )) {
                    $bgimage = ' style="background: url( ' . "'{$image->guid}'" . ' ) repeat;"';
                }
            }
            
            $result .= '<div class="ipsw-content clearfix"' . $bgimage . '>';
            if ( $style == 'style1' ) {
                $result .= $html_title;
                $result .= '<div class="ipsw-content-main clearfix">';
                $result .= $html_desc;
                $result .= $html_photo;
                $result .= '</div>';
            
            } elseif ( $style == 'style2' ) {
                $result .= '<div class="ipsw-content-main">';
                $result .= $html_title;
                $result .= $html_desc;
                $result .= '</div>';
                $result .= $html_photo;
                
            } elseif ( $style == 'style3' ) {
                $result .= '<div class="ipsw-content-sec">';
                $result .= $html_photo;
                $result .= $html_soc;
                $result .= '</div>';
            }
            $result .= '</div>';
            
            $result .= '<div class="ipsw-footer clearfix">';
            if ( $style == 'style1' || $style == 'style2' ) {
                $result .= $html_info;
                $result .= $html_soc;
            
            } elseif ( $style == 'style3' ) {
                $result .= '<div class="ipsw-content-main">';
                $result .= $html_title;
                $result .= $html_desc;
                $result .= $html_info;
                $result .= '</div>';
            }
            $result .= '</div>
                        <div class="ipsw-widget-popup-close">
                            <a href="">x</a>
                        </div>';
            
            $result .= '    </div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Create email widget preview
         *
         * @return string
         */
        public function emailPreview()
        {
            $preview = '
            <h3>Post Content</h3>
            <div class="preview-item preview-post">
                ' . $this->emailPost() .'
            </div>
            <h3>Widget</h3>
            <div class="preview-item preview-widget">
                ' . $this->emailWidget() .'
            </div>
            <h3>Page Popup</h3>
            <div class="preview-item preview-popup">
                ' . $this->emailPopup() .'
            </div>';
            
            return $preview;
        }
        
        /**
         * Create email post content
         *
         * @return string
         */
        public function emailPost()
        {
            if ( ! $this->_widget ) {
                return '';
            }
            $setting    = new IPSocialWidget_Setting( $this->_widgetId );
            $style      = $setting->getSetting( 'style', 'style1' );
            $photo      = $setting->getSetting( 'photo_profile' );
            $title      = $setting->getSetting( 'title' );
            $clr_title  = $setting->getSetting( 'title_color' );
            $desc       = $setting->getSetting( 'description' );
            $clr_desc   = $setting->getSetting( 'description_color' );
            $label      = $setting->getSetting( 'label' );
            $clr_label  = $setting->getSetting( 'label_color' );
            $email      = $setting->getSetting( 'email' );
            $links      = $setting->getSetting( 'social_links' );
            $font       = $setting->getSetting( 'font_family', 'Arial' );
            $font       = str_replace( '_', ' ', $font );
            
            $html_title = '<h2 class="ipsw-title" style="color: ' . $clr_title . '; font-family: ' . "'$font'" . ';">' . $title . '</h2>';
            $html_desc  = '<p class="ipsw-desc" style="color: ' . $clr_desc . ';">' . $desc . '</p>';
            $html_photo = '';
            if ( ! empty( $photo )) {
                $image      = get_post( $photo );
                $html_photo = '<div class="ipsw-photo-wrap"><div class="ipsw-photo">
                                    <img src="' . $image->guid . '" alt="" />
                               </div></div>';
            }
            $html_email =   '<div class="ipsw-email-link">
                                <a style="color: ' . $clr_label . ';" href="mailto:' . $email . '"><i></i>' . $label . '</a>
                            </div>';
            $html_soc  = '';
            if ( ! empty( $links )) {
                $html_soc = '<div class="ipsw-social">
                                <ul>';
                
                foreach( $links as $link ) {
                    $url = $this->_getSocialHost( $link['type'] ) . $link['url'];
                    $src = plugin_dir_url( dirname(__FILE__) ) . 'img/social/' 
                            . $link['icon'] . '/' . $link['type'] . '.png';
                    $html_soc .= '<li><a href="' . $url . '">
                                    <img src="' . $src . '" alt="' . $link['type'] . '">
                                </a></li>';
                }
                
                $html_soc .= '    </ul>
                            </div>';
            }
            
            $result  = '<div class="ipsw-item ipsw-email ipsw-post ipsw-' . $style . '">
                            <div class="ipsw-inner clearfix" style="font-family: ' . "'$font'" . ';">
                                <div class="ipsw-top clearfix">
                                    ' . $html_email
                                      . $html_soc . '
                                </div>
                                <div class="ipsw-content">
                                <div class="ipsw-content-inner clearfix">
                                    ' . $html_photo . '
                                    <div class="ipsw-content-main">
                                    ' . $html_title
                                      . $html_desc . '
                                    </div>
                                </div>
                                </div>
                            </div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Create email widget content
         *
         * @return string
         */
        public function emailWidget()
        {
            if ( ! $this->_widget ) {
                return '';
            }
            $setting    = new IPSocialWidget_Setting( $this->_widgetId );
            $style      = $setting->getSetting( 'style', 'style1' );
            $photo      = $setting->getSetting( 'photo_profile' );
            $title      = $setting->getSetting( 'title' );
            $clr_title  = $setting->getSetting( 'title_color' );
            $desc       = $setting->getSetting( 'description' );
            $clr_desc   = $setting->getSetting( 'description_color' );
            $label      = $setting->getSetting( 'label' );
            $clr_label  = $setting->getSetting( 'label_color' );
            $email      = $setting->getSetting( 'email' );
            $links      = $setting->getSetting( 'social_links' );
            $font       = $setting->getSetting( 'font_family', 'Arial' );
            $font       = str_replace( '_', ' ', $font );
            
            $html_title = '<h2 class="ipsw-title" style="color: ' . $clr_title . '; font-family: ' . "'$font'" . ';">' . $title . '</h2>';
            $html_desc  = '<p class="ipsw-desc" style="color: ' . $clr_desc . ';">' . $desc . '</p>';
            $html_photo = '';
            if ( ! empty( $photo )) {
                $image      = get_post( $photo );
                $html_photo = '<div class="ipsw-photo-wrap"><div class="ipsw-photo">
                                    <img src="' . $image->guid . '" alt="" />
                               </div></div>';
            }
            $html_email =   '<div class="ipsw-email-link">
                                <a style="color: ' . $clr_label . ';" href="mailto:' . $email . '"><i></i>' . $label . '</a>
                            </div>';
            $html_soc  = '';
            if ( ! empty( $links )) {
                $html_soc = '<div class="ipsw-social">
                                <ul>';
                
                foreach( $links as $link ) {
                    $url = $this->_getSocialHost( $link['type'] ) . $link['url'];
                    $src = plugin_dir_url( dirname(__FILE__) ) . 'img/social/' 
                            . $link['icon'] . '/' . $link['type'] . '.png';
                    $html_soc .= '<li><a href="' . $url . '">
                                    <img src="' . $src . '" alt="' . $link['type'] . '">
                                </a></li>';
                }
                
                $html_soc .= '    </ul>
                            </div>';
            }
            
            $result  = '<div class="ipsw-item ipsw-email ipsw-widget ipsw-' . $style . '">
                            <div class="ipsw-inner clearfix" style="font-family: ' . "'$font'" . ';">
                                <div class="ipsw-content">';
            
                                if ( $style == 'style1' ) {
                                    $result .= '<div class="ipsw-content-inner clearfix">';
                                    $result .= '<div class="ipsw-content-main">';
                                    $result .= $html_title;
                                    $result .= $html_desc;
                                    $result .= '</div>';
                                    $result .= $html_photo;
                                    $result .= '</div>';
                                    $result .= $html_email;
                                
                                } elseif ( $style == 'style2' ) {
                                    $result .= $html_email;
                                    $result .= '<div class="ipsw-content-inner clearfix">';
                                    $result .= '<div class="ipsw-content-main">';
                                    $result .= $html_title;
                                    $result .= $html_desc;
                                    $result .= '</div>';
                                    $result .= $html_photo;
                                    $result .= '</div>';
                                    
                                } elseif ( $style == 'style3' ) {
                                    $result .= '<div class="ipsw-content-inner clearfix">';
                                    $result .= '<div class="ipsw-content-main">';
                                    $result .= $html_title;
                                    $result .= $html_desc;
                                    $result .= '</div>';
                                    $result .= $html_photo;
                                    $result .= '</div>';
                                }
            
            $result .= '        </div>
                                <div class="ipsw-footer clearfix">';
                                
                                if ( $style == 'style1' || $style == 'style2' ) {
                                    $result .= $html_soc;
                                    
                                } elseif ( $style == 'style3' ) {
                                    $result .= $html_email;
                                    $result .= $html_soc;
                                }
                                
            $result .= '        </div>
                            </div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Create email popup content
         *
         * @return string
         */
        public function emailPopup()
        {
            if ( ! $this->_widget ) {
                return '';
            }
            $setting    = new IPSocialWidget_Setting( $this->_widgetId );
            $style      = $setting->getSetting( 'style', 'style1' );
            $photo      = $setting->getSetting( 'photo_profile' );
            $title      = $setting->getSetting( 'title' );
            $clr_title  = $setting->getSetting( 'title_color' );
            $desc       = $setting->getSetting( 'description' );
            $clr_desc   = $setting->getSetting( 'description_color' );
            $label      = $setting->getSetting( 'label' );
            $clr_label  = $setting->getSetting( 'label_color' );
            $email      = $setting->getSetting( 'email' );
            $links      = $setting->getSetting( 'social_links' );
            $font       = $setting->getSetting( 'font_family', 'Arial' );
            $font       = str_replace( '_', ' ', $font );
            
            $html_title = '<h2 class="ipsw-title" style="color: ' . $clr_title . '; font-family: ' . "'$font'" . ';">' . $title . '</h2>';
            $html_desc  = '<p class="ipsw-desc" style="color: ' . $clr_desc . ';">' . $desc . '</p>';
            $html_photo = '';
            if ( ! empty( $photo )) {
                $image      = get_post( $photo );
                $html_photo = '<div class="ipsw-photo-wrap"><div class="ipsw-photo">
                                    <img src="' . $image->guid . '" alt="" />
                               </div></div>';
            }
            $html_email =   '<div class="ipsw-email-link">
                                <a style="color: ' . $clr_label . ';" href="mailto:' . $email . '"><i></i>' . $label . '</a>
                            </div>';
            $html_soc  = '';
            if ( ! empty( $links )) {
                $html_soc = '<div class="ipsw-social">
                                <ul>';
                
                foreach( $links as $link ) {
                    $url = $this->_getSocialHost( $link['type'] ) . $link['url'];
                    $src = plugin_dir_url( dirname(__FILE__) ) . 'img/social/' 
                            . $link['icon'] . '/' . $link['type'] . '.png';
                    $html_soc .= '<li><a href="' . $url . '">
                                    <img src="' . $src . '" alt="' . $link['type'] . '">
                                </a></li>';
                }
                
                $html_soc .= '    </ul>
                            </div>';
            }
            
            $result  = '<div class="ipsw-item ipsw-email ipsw-popup ipsw-' . $style . '">
                            <div class="ipsw-inner clearfix" style="font-family: ' . "'$font'" . ';">
                                <div class="ipsw-top clearfix">
                                    ' . $html_email
                                      . $html_soc . '
                                </div>
                                <div class="ipsw-content">
                                <div class="ipsw-content-inner clearfix">
                                    ' . $html_photo . '
                                    <div class="ipsw-content-main">
                                    ' . $html_title
                                      . $html_desc . '
                                    </div>
                                </div>
                                </div>
                                <div class="ipsw-widget-popup-close">
                                    <a href="">x</a>
                                </div>
                            </div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Create sales widget preview
         *
         * @return string
         */
        public function salesPreview()
        {
            $preview = '
            <h3>Post Content</h3>
            <div class="preview-item preview-post">
                ' . $this->salesPost() .'
            </div>
            <h3>Widget</h3>
            <div class="preview-item preview-widget">
                ' . $this->salesWidget() .'
            </div>
            <h3>Page Popup</h3>
            <div class="preview-item preview-popup">
                ' . $this->salesPopup() .'
            </div>';
            
            return $preview;
        }
        
        /**
         * Create sales post content
         *
         * @return string
         */
        public function salesPost()
        {
            if ( ! $this->_widget ) {
                return '';
            }
            $setting    = new IPSocialWidget_Setting( $this->_widgetId );
            $style      = $setting->getSetting( 'style', 'style1' );
            $prodimg    = $setting->getSetting( 'product_image' );
            $title      = $setting->getSetting( 'title' );
            $clr_title  = $setting->getSetting( 'title_color' );
            $desc       = $setting->getSetting( 'description' );
            $clr_desc   = $setting->getSetting( 'description_color' );
            $price      = $setting->getSetting( 'price' );
            $label      = $setting->getSetting( 'label' );
            $url        = $setting->getSetting( 'url' );
            $permalink  = $setting->getSetting( 'permalink' );
            $links      = $setting->getSetting( 'social_links' );
            $footer     = $setting->getSetting( 'footer_text' );
            $clr_footer = $setting->getSetting( 'footer_text_color' );
            $font       = $setting->getSetting( 'font_family', 'Arial' );
            $font       = str_replace( '_', ' ', $font );
            
            $html_title = '<h2 class="ipsw-title" style="color: ' . $clr_title . '; font-family: ' . "'$font'" . ';">' . $title . '</h2>';
            $html_desc  = '<p class="ipsw-desc" style="color: ' . $clr_desc . ';">' . $desc . '</p>';
            $html_price = '<div class="ipsw-price"><strong>' . $price . '</strong></div>';
            $html_buy   = '<div class="ipsw-buy-button">
                                <a href="' . $url . '">' . $label . '</a>
                            </div>';
            $html_photo = '';
            if ( ! empty( $prodimg )) {
                $image      = get_post( $prodimg );
                $html_photo = '<div class="ipsw-photo">
                                    <img src="' . $image->guid . '" alt="" />
                               </div>';
            }
            
            $html_soc  = '';
            if ( ! empty( $links )) {
                $html_soc = '<div class="ipsw-social">
                                <ul>';
                
                foreach( $links as $link ) {
                    $url = $this->_getSocialHost( $link['type'] ) . $link['url'];
                    $src = plugin_dir_url( dirname(__FILE__) ) . 'img/social/' 
                            . $link['icon'] . '/' . $link['type'] . '.png';
                    $html_soc .= '<li><a href="' . $url . '">
                                    <img src="' . $src . '" alt="' . $link['type'] . '">
                                </a></li>';
                }
                
                $html_soc .= '    </ul>
                            </div>';
            }
            
            $html_info = '<div class="ipsw-footer-text">
                            <em style="color: ' . $clr_footer . ';">' . $footer . '</em>
                          </div>';
            
            $result  = '<div class="ipsw-item ipsw-sales ipsw-post ipsw-' . $style . '">
                            <div class="ipsw-inner clearfix" style="font-family: ' . "'$font'" . ';">';
            
            $result .= '<div class="ipsw-content clearfix">
                            <div class="ipsw-photo-wrap">
                                ' . $html_photo . '
                            </div>
                            <div class="ipsw-content-main clearfix">
                                <div class="ipsw-info">
                                    ' . $html_title .
                                        $html_desc  . '
                                </div>
                                <div class="ipsw-buy-product clearfix">
                                    ' . $html_price .
                                        $html_buy  . '
                                </div>
                            </div>
                        </div>';
            
            $result .= '<div class="ipsw-footer clearfix">' 
                            . $html_info 
                            . $html_soc .
                       '</div>';
            
            $result .= '    </div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Create sales widget content
         *
         * @return string
         */
        public function salesWidget()
        {
            if ( ! $this->_widget ) {
                return '';
            }
            $setting    = new IPSocialWidget_Setting( $this->_widgetId );
            $style      = $setting->getSetting( 'style', 'style1' );
            $prodimg    = $setting->getSetting( 'product_image' );
            $title      = $setting->getSetting( 'title' );
            $clr_title  = $setting->getSetting( 'title_color' );
            $desc       = $setting->getSetting( 'description' );
            $clr_desc   = $setting->getSetting( 'description_color' );
            $price      = $setting->getSetting( 'price' );
            $label      = $setting->getSetting( 'label' );
            $url        = $setting->getSetting( 'url' );
            $permalink  = $setting->getSetting( 'permalink' );
            $links      = $setting->getSetting( 'social_links' );
            $footer     = $setting->getSetting( 'footer_text' );
            $clr_footer = $setting->getSetting( 'footer_text_color' );
            $font       = $setting->getSetting( 'font_family', 'Arial' );
            $font       = str_replace( '_', ' ', $font );
            
            $html_title = '<h2 class="ipsw-title" style="color: ' . $clr_title . '; font-family: ' . "'$font'" . ';">' . $title . '</h2>';
            $html_desc  = '<p class="ipsw-desc" style="color: ' . $clr_desc . ';">' . $desc . '</p>';
            $html_price = '<div class="ipsw-price"><strong>' . $price . '</strong></div>';
            $html_buy   = '<div class="ipsw-buy-button">
                                <a href="' . $url . '">' . $label . '</a>
                            </div>';
            $html_photo = '';
            if ( ! empty( $prodimg )) {
                $image      = get_post( $prodimg );
                $html_photo = '<div class="ipsw-photo-wrap"><div class="ipsw-photo">
                                    <img src="' . $image->guid . '" alt="" />
                               </div></div>';
            }
            
            $html_soc  = '';
            if ( ! empty( $links )) {
                $html_soc = '<div class="ipsw-social">
                                <ul>';
                
                foreach( $links as $link ) {
                    $url = $this->_getSocialHost( $link['type'] ) . $link['url'];
                    $src = plugin_dir_url( dirname(__FILE__) ) . 'img/social/' 
                            . $link['icon'] . '/' . $link['type'] . '.png';
                    $html_soc .= '<li><a href="' . $url . '">
                                    <img src="' . $src . '" alt="' . $link['type'] . '">
                                </a></li>';
                }
                
                $html_soc .= '    </ul>
                            </div>';
            }
            
            $html_info = '<div class="ipsw-footer-text">
                            <em style="color: ' . $clr_footer . ';">' . $footer . '</em>
                          </div>';
            
            $result  = '<div class="ipsw-item ipsw-sales ipsw-widget ipsw-' . $style . '">
                            <div class="ipsw-inner clearfix" style="font-family: ' . "'$font'" . ';">';
            
            $result .= '<div class="ipsw-content clearfix">';
            $result .= $html_title;
            if ( $style == 'style1' ) {
                $result .= $html_photo;
                $result .= $html_desc;
            }
            else if ( $style == 'style2' ) {
                $result .= $html_photo;
            }
            else if ( $style == 'style3' ) {
                $result .= '<div class="ipsw-content-main clearfix">';
                $result .= $html_photo;
                $result .= '<div class="ipsw-buy-product clearfix">
                                ' . $html_price .
                                    $html_buy  . '
                            </div>';
                $result .= '</div>';
                $result .= $html_desc;
            }
            $result .= '</div>';
            
            $result .= '<div class="ipsw-footer clearfix">';
            if ( $style == 'style1' ) {
                $result .= '<div class="ipsw-buy-product clearfix">
                                ' . $html_price .
                                    $html_buy  . '
                            </div>';
                $result .= $html_soc;
            }
            else if ( $style == 'style2' ) {
                $result .= $html_desc;
                $result .= '<div class="ipsw-buy-product clearfix">
                                ' . $html_price .
                                    $html_buy  . '
                            </div>';
                $result .= $html_soc;
            }
            else if ( $style == 'style3' ) {
                $result .= $html_soc;
            }
            $result .= '</div>';
            
            $result .= '    </div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Create sales popup content
         *
         * @return string
         */
        public function salesPopup()
        {
            if ( ! $this->_widget ) {
                return '';
            }
            $setting    = new IPSocialWidget_Setting( $this->_widgetId );
            $style      = $setting->getSetting( 'style', 'style1' );
            $prodimg    = $setting->getSetting( 'product_image' );
            $title      = $setting->getSetting( 'title' );
            $clr_title  = $setting->getSetting( 'title_color' );
            $desc       = $setting->getSetting( 'description' );
            $clr_desc   = $setting->getSetting( 'description_color' );
            $price      = $setting->getSetting( 'price' );
            $label      = $setting->getSetting( 'label' );
            $url        = $setting->getSetting( 'url' );
            $permalink  = $setting->getSetting( 'permalink' );
            $links      = $setting->getSetting( 'social_links' );
            $footer     = $setting->getSetting( 'footer_text' );
            $clr_footer = $setting->getSetting( 'footer_text_color' );
            $font       = $setting->getSetting( 'font_family', 'Arial' );
            $font       = str_replace( '_', ' ', $font );
            
            $html_title = '<h2 class="ipsw-title" style="color: ' . $clr_title . '; font-family: ' . "'$font'" . ';">' . $title . '</h2>';
            $html_desc  = '<p class="ipsw-desc" style="color: ' . $clr_desc . ';">' . $desc . '</p>';
            $html_price = '<div class="ipsw-price"><strong>' . $price . '</strong></div>';
            $html_buy   = '<div class="ipsw-buy-button">
                                <a href="' . $url . '">' . $label . '</a>
                            </div>';
            $html_photo = '';
            if ( ! empty( $prodimg )) {
                $image      = get_post( $prodimg );
                $html_photo = '<div class="ipsw-photo">
                                    <img src="' . $image->guid . '" alt="" />
                               </div>';
            }
            
            $html_soc  = '';
            if ( ! empty( $links )) {
                $html_soc = '<div class="ipsw-social">
                                <ul>';
                
                foreach( $links as $link ) {
                    $url = $this->_getSocialHost( $link['type'] ) . $link['url'];
                    $src = plugin_dir_url( dirname(__FILE__) ) . 'img/social/' 
                            . $link['icon'] . '/' . $link['type'] . '.png';
                    $html_soc .= '<li><a href="' . $url . '">
                                    <img src="' . $src . '" alt="' . $link['type'] . '">
                                </a></li>';
                }
                
                $html_soc .= '    </ul>
                            </div>';
            }
            
            $html_info = '<div class="ipsw-footer-text">
                            <em style="color: ' . $clr_footer . ';">' . $footer . '</em>
                          </div>';
            
            $result  = '<div class="ipsw-item ipsw-sales ipsw-popup ipsw-' . $style . '">
                            <div class="ipsw-inner clearfix" style="font-family: ' . "'$font'" . ';">';
            
            $result .= '<div class="ipsw-content clearfix">
                            <div class="ipsw-photo-wrap">
                                ' . $html_photo . '
                            </div>
                            <div class="ipsw-content-main clearfix">
                                <div class="ipsw-info">
                                    ' . $html_title .
                                        $html_desc  . '
                                </div>
                                <div class="ipsw-buy-product clearfix">
                                    ' . $html_price .
                                        $html_buy  . '
                                </div>
                            </div>
                        </div>';
            
            $result .= '<div class="ipsw-footer clearfix">' 
                            . $html_info 
                            . $html_soc .
                       '</div>
                       <div class="ipsw-widget-popup-close">
                            <a href="">x</a>
                        </div>';
            
            $result .= '    </div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Create profile widget preview
         *
         * @return string
         */
        public function profilePreview()
        {
            $preview = '
            <h3>Post Content</h3>
            <div class="preview-item preview-post">
                ' . $this->profilePost() .'
            </div>
            <h3>Widget</h3>
            <div class="preview-item preview-widget">
                ' . $this->profileWidget() .'
            </div>
            <h3>Page Popup</h3>
            <div class="preview-item preview-popup">
                ' . $this->profilePopup() .'
            </div>';
            
            return $preview;
        }
        
        /**
         * Create profile post content
         *
         * @return string
         */
        public function profilePost()
        {
            if ( ! $this->_widget ) {
                return '';
            }
            $setting    = new IPSocialWidget_Setting( $this->_widgetId );
            $style      = $setting->getSetting( 'style', 'style1' );
            $bgimage    = $setting->getSetting( 'background_image' );
            $photo      = $setting->getSetting( 'photo_profile' );
            $title      = $setting->getSetting( 'title' );
            $clr_title  = $setting->getSetting( 'title_color' );
            $desc       = $setting->getSetting( 'description' );
            $clr_desc   = $setting->getSetting( 'description_color' );
            $label      = $setting->getSetting( 'label' );
            $clr_label  = $setting->getSetting( 'label_color' );
            $permalink  = $setting->getSetting( 'permalink' );
            $links      = $setting->getSetting( 'social_links' );
            $font       = $setting->getSetting( 'font_family', 'Arial' );
            $font       = str_replace( '_', ' ', $font );
            
            $html_title = '<h2 class="ipsw-title" style="color: ' . $clr_title . '; font-family: ' . "'$font'" . ';">' . $title . '</h2>';
            $html_desc  = '<p class="ipsw-desc" style="color: ' . $clr_desc . ';">' . $desc . '</p>';
            $html_photo = '';
            if ( ! empty( $photo )) {
                $image      = get_post( $photo );
                $html_photo = '<div class="ipsw-photo">
                                    <img src="' . $image->guid . '" alt="" />
                               </div>';
            }
            $html_more =   '<div class="ipsw-more-link">
                                <a style="color: ' . $clr_label . ';" href="' . $permalink . '"><i></i>' . $label . '</a>
                            </div>';
            
            $html_soc  = '';
            if ( ! empty( $links )) {
                $html_soc = '<div class="ipsw-social">
                                <ul>';
                
                foreach( $links as $link ) {
                    $url = $this->_getSocialHost( $link['type'] ) . $link['url'];
                    $src = plugin_dir_url( dirname(__FILE__) ) . 'img/social/' 
                            . $link['icon'] . '/' . $link['type'] . '.png';
                    $html_soc .= '<li><a href="' . $url . '">
                                    <img src="' . $src . '" alt="' . $link['type'] . '">
                                </a></li>';
                }
                
                $html_soc .= '    </ul>
                            </div>';
            }
            
            $result  = '<div class="ipsw-item ipsw-profile ipsw-post ipsw-' . $style . '">
                            <div class="ipsw-inner clearfix" style="font-family: ' . "'$font'" . ';">';
            
            if ( ! empty( $bgimage )) {
                $image   = get_post( $bgimage );
                $bgimage = '';
                if ( ! empty( $image->guid )) {
                    $bgimage = ' style="background: url( ' . "'{$image->guid}'" . ' ) repeat;"';
                }
            }
            
            $result .= '<div class="ipsw-content clearfix"' . $bgimage . '>';
            $result .= $html_photo;
            $result .= '<div class="ipsw-content-main">';
            $result .= $html_title;
            $result .= $html_desc;
            $result .= $html_more;
            $result .= '</div>';
            $result .= '</div>';
            
            $result .= '<div class="ipsw-footer clearfix">' . $html_soc . '</div>';
            
            $result .= '    </div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Create profile widget content
         *
         * @return string
         */
        public function profileWidget()
        {
            if ( ! $this->_widget ) {
                return '';
            }
            $setting    = new IPSocialWidget_Setting( $this->_widgetId );
            $style      = $setting->getSetting( 'style', 'style1' );
            $bgimage    = $setting->getSetting( 'background_image' );
            $photo      = $setting->getSetting( 'photo_profile' );
            $title      = $setting->getSetting( 'title' );
            $clr_title  = $setting->getSetting( 'title_color' );
            $desc       = $setting->getSetting( 'description' );
            $clr_desc   = $setting->getSetting( 'description_color' );
            $label      = $setting->getSetting( 'label' );
            $clr_label  = $setting->getSetting( 'label_color' );
            $permalink  = $setting->getSetting( 'permalink' );
            $links      = $setting->getSetting( 'social_links' );
            $font       = $setting->getSetting( 'font_family', 'Arial' );
            $font       = str_replace( '_', ' ', $font );
            
            $html_title = '<h2 class="ipsw-title" style="color: ' . $clr_title . '; font-family: ' . "'$font'" . ';">' . $title . '</h2>';
            $html_desc  = '<p class="ipsw-desc" style="color: ' . $clr_desc . ';">' . $desc . '</p>';
            $html_photo = '';
            if ( ! empty( $photo )) {
                $image      = get_post( $photo );
                $html_photo = '<div class="ipsw-photo">
                                    <img src="' . $image->guid . '" alt="" />
                               </div>';
            }
            $html_more =   '<div class="ipsw-more-link">
                                <a style="color: ' . $clr_label . ';" href="' . $permalink . '"><i></i>' . $label . '</a>
                            </div>';
            
            $html_soc  = '';
            if ( ! empty( $links )) {
                $html_soc = '<div class="ipsw-social">
                                <ul>';
                
                foreach( $links as $link ) {
                    $url = $this->_getSocialHost( $link['type'] ) . $link['url'];
                    $src = plugin_dir_url( dirname(__FILE__) ) . 'img/social/' 
                            . $link['icon'] . '/' . $link['type'] . '.png';
                    $html_soc .= '<li><a href="' . $url . '">
                                    <img src="' . $src . '" alt="' . $link['type'] . '">
                                </a></li>';
                }
                
                $html_soc .= '    </ul>
                            </div>';
            }
            
            $result  = '<div class="ipsw-item ipsw-profile ipsw-widget ipsw-' . $style . '">
                            <div class="ipsw-inner clearfix" style="font-family: ' . "'$font'" . ';">';
            
            if ( ! empty( $bgimage )) {
                $image   = get_post( $bgimage );
                $bgimage = '';
                if ( ! empty( $image->guid )) {
                    $bgimage = ' style="background: url( ' . "'{$image->guid}'" . ' ) repeat;"';
                }
            }
            
            $result .= '<div class="ipsw-content clearfix"' . $bgimage . '>';
            $result .= $html_photo;
            $result .= '<div class="ipsw-content-main">';
            $result .= $html_title;
            $result .= $html_desc;
            $result .= $html_more;
            $result .= '</div>';
            $result .= '</div>';
            
            $result .= '<div class="ipsw-footer clearfix">' . $html_soc . '</div>';
            
            $result .= '    </div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Create profile popup content
         *
         * @return string
         */
        public function profilePopup()
        {
            if ( ! $this->_widget ) {
                return '';
            }
            $setting    = new IPSocialWidget_Setting( $this->_widgetId );
            $style      = $setting->getSetting( 'style', 'style1' );
            $bgimage    = $setting->getSetting( 'background_image' );
            $photo      = $setting->getSetting( 'photo_profile' );
            $title      = $setting->getSetting( 'title' );
            $clr_title  = $setting->getSetting( 'title_color' );
            $desc       = $setting->getSetting( 'description' );
            $clr_desc   = $setting->getSetting( 'description_color' );
            $label      = $setting->getSetting( 'label' );
            $clr_label  = $setting->getSetting( 'label_color' );
            $permalink  = $setting->getSetting( 'permalink' );
            $links      = $setting->getSetting( 'social_links' );
            $font       = $setting->getSetting( 'font_family', 'Arial' );
            $font       = str_replace( '_', ' ', $font );
            
            $html_title = '<h2 class="ipsw-title" style="color: ' . $clr_title . '; font-family: ' . "'$font'" . ';">' . $title . '</h2>';
            $html_desc  = '<p class="ipsw-desc" style="color: ' . $clr_desc . ';">' . $desc . '</p>';
            $html_photo = '';
            if ( ! empty( $photo )) {
                $image      = get_post( $photo );
                $html_photo = '<div class="ipsw-photo">
                                    <img src="' . $image->guid . '" alt="" />
                               </div>';
            }
            $html_more =   '<div class="ipsw-more-link">
                                <a style="color: ' . $clr_label . ';" href="' . $permalink . '"><i></i>' . $label . '</a>
                            </div>';
            
            $html_soc  = '';
            if ( ! empty( $links )) {
                $html_soc = '<div class="ipsw-social">
                                <ul>';
                
                foreach( $links as $link ) {
                    $url = $this->_getSocialHost( $link['type'] ) . $link['url'];
                    $src = plugin_dir_url( dirname(__FILE__) ) . 'img/social/' 
                            . $link['icon'] . '/' . $link['type'] . '.png';
                    $html_soc .= '<li><a href="' . $url . '">
                                    <img src="' . $src . '" alt="' . $link['type'] . '">
                                </a></li>';
                }
                
                $html_soc .= '    </ul>
                            </div>';
            }
            
            $result  = '<div class="ipsw-item ipsw-profile ipsw-popup ipsw-' . $style . '">
                            <div class="ipsw-inner clearfix" style="font-family: ' . "'$font'" . ';">';
            
            if ( ! empty( $bgimage )) {
                $image   = get_post( $bgimage );
                $bgimage = '';
                if ( ! empty( $image->guid )) {
                    $bgimage = ' style="background: url( ' . "'{$image->guid}'" . ' ) repeat;"';
                }
            }
            
            $result .= '<div class="ipsw-content clearfix"' . $bgimage . '>';
            $result .= $html_photo;
            $result .= '<div class="ipsw-content-main">';
            $result .= $html_title;
            $result .= $html_desc;
            $result .= $html_more;
            $result .= '</div>';
            $result .= '</div>';
            
            $result .= '<div class="ipsw-footer clearfix">' . $html_soc . '</div>
                        <div class="ipsw-widget-popup-close">
                            <a href="">x</a>
                        </div>';
            
            $result .= '    </div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Create contact widget preview
         *
         * @return string
         */
        public function contactPreview()
        {
            $preview = '
            <h3>Post Content</h3>
            <div class="preview-item preview-post">
                ' . $this->contactPost() .'
            </div>
            <h3>Widget</h3>
            <div class="preview-item preview-widget">
                ' . $this->contactWidget() .'
            </div>
            <h3>Page Popup</h3>
            <div class="preview-item preview-popup">
                ' . $this->contactPopup() .'
            </div>';
            
            return $preview;
        }
        
        /**
         * Create contact post content
         *
         * @return string
         */
        public function contactPost()
        {
            if ( ! $this->_widget ) {
                return '';
            }
            $setting    = new IPSocialWidget_Setting( $this->_widgetId );
            $style      = $setting->getSetting( 'style', 'style1' );
            $photo      = $setting->getSetting( 'photo_profile' );
            $name       = $setting->getSetting( 'name' );
            $clr_name   = $setting->getSetting( 'name_color' );
            $address    = $setting->getSetting( 'address' );
            $email      = $setting->getSetting( 'email' );
            $phone      = $setting->getSetting( 'phone' );
            $mobile     = $setting->getSetting( 'mobile' );
            $fax        = $setting->getSetting( 'fax' );
            $color      = $setting->getSetting( 'color' );
            $links      = $setting->getSetting( 'social_links' );
            $font       = $setting->getSetting( 'font_family', 'Arial' );
            $font       = str_replace( '_', ' ', $font );
            
            $html_name  = '<h2 class="ipsw-title" style="color: ' . $clr_name . '; font-family: ' . "'$font'" . ';">' . $name . '</h2>';
            $html_photo = '';
            if ( ! empty( $photo )) {
                $image      = get_post( $photo );
                $html_photo = '<div class="ipsw-photo-wrap"><div class="ipsw-photo">
                                    <img src="' . $image->guid . '" alt="" />
                               </div></div>';
            }
            $html_soc  = '';
            if ( ! empty( $links )) {
                $html_soc = '<div class="ipsw-social">
                                <ul>';
                
                foreach( $links as $link ) {
                    $url = $this->_getSocialHost( $link['type'] ) . $link['url'];
                    $src = plugin_dir_url( dirname(__FILE__) ) . 'img/social/' 
                            . $link['icon'] . '/' . $link['type'] . '.png';
                    $html_soc .= '<li><a href="' . $url . '">
                                    <img src="' . $src . '" alt="' . $link['type'] . '">
                                </a></li>';
                }
                
                $html_soc .= '    </ul>
                            </div>';
            }
            $html_cnt = '<div class="ipsw-contact-detail">
                            <div class="ipsw-address">
                                <i></i> <span>' . $address . '</span>
                            </div>
                            <div class="ipsw-email ipsw-contact-item">
                                <i></i> <span>' . $email . '</span>
                            </div>
                            <div class="ipsw-phone ipsw-contact-item">
                                <i></i> <span>' . $phone . '</span>
                            </div>
                            <div class="ipsw-mobile ipsw-contact-item">
                                <i></i> <span>' . $mobile . '</span>
                            </div>
                            <div class="ipsw-fax ipsw-contact-item">
                                <i></i> <span>' . $fax . '</span>
                            </div>
                         </div>';
            
            $result  = '<div class="ipsw-item ipsw-contact ipsw-post ipsw-' . $style . '">
                            <div class="ipsw-inner clearfix" style="font-family: ' . "'$font'" . ';">';
            
            $result .= '<div class="ipsw-content clearfix">';
            $result .= $html_photo;
            $result .= '<div class="ipsw-content-main">';
            $result .= $html_name;
            $result .= $html_cnt;
            $result .= '</div>';
            $result .= '</div>';
            
            $result .= '<div class="ipsw-footer clearfix">' . $html_soc . '</div>';
            
            $result .= '    </div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Create contact widget content
         *
         * @return string
         */
        public function contactWidget()
        {
            if ( ! $this->_widget ) {
                return '';
            }
            $setting    = new IPSocialWidget_Setting( $this->_widgetId );
            $style      = $setting->getSetting( 'style', 'style1' );
            $photo      = $setting->getSetting( 'photo_profile' );
            $name       = $setting->getSetting( 'name' );
            $clr_name   = $setting->getSetting( 'name_color' );
            $address    = $setting->getSetting( 'address' );
            $email      = $setting->getSetting( 'email' );
            $phone      = $setting->getSetting( 'phone' );
            $mobile     = $setting->getSetting( 'mobile' );
            $fax        = $setting->getSetting( 'fax' );
            $color      = $setting->getSetting( 'color' );
            $links      = $setting->getSetting( 'social_links' );
            $font       = $setting->getSetting( 'font_family', 'Arial' );
            $font       = str_replace( '_', ' ', $font );
            
            $html_name  = '<h2 class="ipsw-title" style="color: ' . $clr_name . '; font-family: ' . "'$font'" . ';">' . $name . '</h2>';
            $html_photo = '';
            if ( ! empty( $photo )) {
                $image      = get_post( $photo );
                $html_photo = '<div class="ipsw-photo-wrap"><div class="ipsw-photo">
                                    <img src="' . $image->guid . '" alt="" />
                               </div></div>';
            }
            $html_soc  = '';
            if ( ! empty( $links )) {
                $html_soc = '<div class="ipsw-social">
                                <ul>';
                
                foreach( $links as $link ) {
                    $url = $this->_getSocialHost( $link['type'] ) . $link['url'];
                    $src = plugin_dir_url( dirname(__FILE__) ) . 'img/social/' 
                            . $link['icon'] . '/' . $link['type'] . '.png';
                    $html_soc .= '<li><a href="' . $url . '">
                                    <img src="' . $src . '" alt="' . $link['type'] . '">
                                </a></li>';
                }
                
                $html_soc .= '    </ul>
                            </div>';
            }
            $html_cnt = '<div class="ipsw-contact-detail">
                            <div class="ipsw-address">
                                <i></i> <span>' . $address . '</span>
                            </div>
                            <div class="ipsw-email ipsw-contact-item">
                                <i></i> <span>' . $email . '</span>
                            </div>
                            <div class="ipsw-phone ipsw-contact-item">
                                <i></i> <span>' . $phone . '</span>
                            </div>
                            <div class="ipsw-mobile ipsw-contact-item">
                                <i></i> <span>' . $mobile . '</span>
                            </div>
                            <div class="ipsw-fax ipsw-contact-item">
                                <i></i> <span>' . $fax . '</span>
                            </div>
                         </div>';
            
            $result  = '<div class="ipsw-item ipsw-contact ipsw-widget ipsw-' . $style . '">
                            <div class="ipsw-inner clearfix" style="font-family: ' . "'$font'" . ';">';
            
            if ( $style == 'style1' || $style == 'style2' ) {
                $result .= '<div class="ipsw-content">
                                <div class="ipsw-top clearfix">
                                    ' . $html_photo 
                                      . $html_name . '
                                </div>
                                <div class="ipsw-contact-detail">
                                    <ul>
                                        <li class="ipsw-address">
                                            <i></i> <span>' . $address . '</span>
                                        </li>
                                        <li class="ipsw-email">
                                            <i></i> <span>' . $email . '</span>
                                        </li>
                                        <li class="ipsw-phone">
                                            <i></i> <span>' . $phone . '</span>
                                        </li>
                                        <li class="ipsw-mobile">
                                            <i></i> <span>' . $mobile . '</span>
                                        </li>
                                        <li class="ipsw-fax">
                                            <i></i> <span>' . $fax . '</span>
                                        </li>
                                    </ul>
                                </div>
                            </div>';
            }
            elseif ( $style == 'style3' ) {
                $result .= '<div class="ipsw-content">
                                <div class="ipsw-top clearfix">' .
                                    $html_photo . '
                                    <div class="ipsw-top-main">
                                        ' . $html_name . '
                                        <div class="ipsw-address">
                                            ' . $address . '
                                        </div>
                                    </div>
                                </div>
                                <div class="ipsw-contact-detail">
                                    <ul>
                                        <li class="ipsw-email">
                                            <i></i> <span>' . $email . '</span>
                                        </li>
                                        <li class="ipsw-phone">
                                            <i></i> <span>' . $phone . '</span>
                                        </li>
                                        <li class="ipsw-mobile">
                                            <i></i> <span>' . $mobile . '</span>
                                        </li>
                                        <li class="ipsw-fax">
                                            <i></i> <span>' . $fax . '</span>
                                        </li>
                                    </ul>
                                </div>
                            </div>';
            }
            
            $result .= '        <div class="ipsw-footer clearfix">' . $html_soc . '</div>';
            $result .= '    </div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Create contact popup content
         *
         * @return string
         */
        public function contactPopup()
        {
            if ( ! $this->_widget ) {
                return '';
            }
            $setting    = new IPSocialWidget_Setting( $this->_widgetId );
            $style      = $setting->getSetting( 'style', 'style1' );
            $photo      = $setting->getSetting( 'photo_profile' );
            $name       = $setting->getSetting( 'name' );
            $clr_name   = $setting->getSetting( 'name_color' );
            $address    = $setting->getSetting( 'address' );
            $email      = $setting->getSetting( 'email' );
            $phone      = $setting->getSetting( 'phone' );
            $mobile     = $setting->getSetting( 'mobile' );
            $fax        = $setting->getSetting( 'fax' );
            $color      = $setting->getSetting( 'color' );
            $links      = $setting->getSetting( 'social_links' );
            $font       = $setting->getSetting( 'font_family', 'Arial' );
            $font       = str_replace( '_', ' ', $font );
            
            $html_name  = '<h2 class="ipsw-title" style="color: ' . $clr_name . '; font-family: ' . "'$font'" . ';">' . $name . '</h2>';
            $html_photo = '';
            if ( ! empty( $photo )) {
                $image      = get_post( $photo );
                $html_photo = '<div class="ipsw-photo-wrap"><div class="ipsw-photo">
                                    <img src="' . $image->guid . '" alt="" />
                               </div></div>';
            }
            $html_soc  = '';
            if ( ! empty( $links )) {
                $html_soc = '<div class="ipsw-social">
                                <ul>';
                
                foreach( $links as $link ) {
                    $url = $this->_getSocialHost( $link['type'] ) . $link['url'];
                    $src = plugin_dir_url( dirname(__FILE__) ) . 'img/social/' 
                            . $link['icon'] . '/' . $link['type'] . '.png';
                    $html_soc .= '<li><a href="' . $url . '">
                                    <img src="' . $src . '" alt="' . $link['type'] . '">
                                </a></li>';
                }
                
                $html_soc .= '    </ul>
                            </div>';
            }
            $html_cnt = '<div class="ipsw-contact-detail">
                            <div class="ipsw-address">
                                <i></i> <span>' . $address . '</span>
                            </div>
                            <div class="ipsw-email ipsw-contact-item">
                                <i></i> <span>' . $email . '</span>
                            </div>
                            <div class="ipsw-phone ipsw-contact-item">
                                <i></i> <span>' . $phone . '</span>
                            </div>
                            <div class="ipsw-mobile ipsw-contact-item">
                                <i></i> <span>' . $mobile . '</span>
                            </div>
                            <div class="ipsw-fax ipsw-contact-item">
                                <i></i> <span>' . $fax . '</span>
                            </div>
                         </div>';
            
            $result  = '<div class="ipsw-item ipsw-contact ipsw-popup ipsw-' . $style . '">
                            <div class="ipsw-inner clearfix" style="font-family: ' . "'$font'" . ';">';
            
            $result .= '<div class="ipsw-content clearfix">';
            $result .= $html_photo;
            $result .= '<div class="ipsw-content-main">';
            $result .= $html_name;
            $result .= $html_cnt;
            $result .= '</div>';
            $result .= '</div>';
            
            $result .= '<div class="ipsw-footer clearfix">' . $html_soc . '</div>
                        <div class="ipsw-widget-popup-close">
                            <a href="">x</a>
                        </div>';
            
            $result .= '    </div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Create link widget preview
         *
         * @return string
         */
        public function linkPreview()
        {
            $preview = '
            <h3>Post Content</h3>
            <div class="preview-item preview-post">
                ' . $this->linkPost() .'
            </div>
            <h3>Widget</h3>
            <div class="preview-item preview-widget">
                ' . $this->linkWidget() .'
            </div>
            <h3>Page Popup</h3>
            <div class="preview-item preview-popup">
                ' . $this->linkPopup() .'
            </div>';
            
            return $preview;
        }
        
        /**
         * Create link post content
         *
         * @return string
         */
        public function linkPost()
        {
            if ( ! $this->_widget ) {
                return '';
            }
            $setting    = new IPSocialWidget_Setting( $this->_widgetId );
            $style      = $setting->getSetting( 'style', 'style1' );
            $title      = $setting->getSetting( 'title' );
            $clr_title  = $setting->getSetting( 'title_color' );
            $links      = $setting->getSetting( 'social_links' );
            $font       = $setting->getSetting( 'font_family', 'Arial' );
            $font       = str_replace( '_', ' ', $font );
            
            $html_title = '<h2 class="ipsw-title" style="color: ' . $clr_title . '; font-family: ' . "'$font'" . ';">' . $title . '</h2>';
            
            $html_soc  = '';
            if ( ! empty( $links )) {
                $html_soc = '<div class="ipsw-social">
                                <ul>';
                
                foreach( $links as $link ) {
                    $url = $this->_getSocialHost( $link['type'] ) . $link['url'];
                    $src = plugin_dir_url( dirname(__FILE__) ) . 'img/social/' 
                            . $link['icon'] . '/' . $link['type'] . '.png';
                    $html_soc .= '<li><a href="' . $url . '">
                                    <img src="' . $src . '" alt="' . $link['type'] . '">
                                    <strong>' . $this->_getSocialTitle( $link['type'] ) . '</strong>
                                </a></li>';
                }
                
                $html_soc .= '    </ul>
                            </div>';
            }
            
            $result  = '<div class="ipsw-item ipsw-link ipsw-post ipsw-' . $style . '">
                            <div class="ipsw-inner clearfix" style="font-family: ' . "'$font'" . ';">
                                <div class="ipsw-top">
                                    ' . $html_title . '
                                </div>' . 
                                $html_soc .
                            '</div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Create link widget content
         *
         * @return string
         */
        public function linkWidget()
        {
            if ( ! $this->_widget ) {
                return '';
            }
            $setting    = new IPSocialWidget_Setting( $this->_widgetId );
            $style      = $setting->getSetting( 'style', 'style1' );
            $title      = $setting->getSetting( 'title' );
            $clr_title  = $setting->getSetting( 'title_color' );
            $links      = $setting->getSetting( 'social_links' );
            $font       = $setting->getSetting( 'font_family', 'Arial' );
            $font       = str_replace( '_', ' ', $font );
            
            $html_title = '<h2 class="ipsw-title" style="color: ' . $clr_title . '; font-family: ' . "'$font'" . ';">' . $title . '</h2>';
            
            $html_soc  = '';
            if ( ! empty( $links )) {
                $html_soc = '<div class="ipsw-social">
                                <ul>';
                
                foreach( $links as $link ) {
                    $url = $this->_getSocialHost( $link['type'] ) . $link['url'];
                    $src = plugin_dir_url( dirname(__FILE__) ) . 'img/social/' 
                            . $link['icon'] . '/' . $link['type'] . '.png';
                    $html_soc .= '<li><a href="' . $url . '">
                                    <img src="' . $src . '" alt="' . $link['type'] . '">
                                    <strong>' . $this->_getSocialTitle( $link['type'] ) . '</strong>
                                </a></li>';
                }
                
                $html_soc .= '    </ul>
                            </div>';
            }
            
            $result  = '<div class="ipsw-item ipsw-link ipsw-widget ipsw-' . $style . '">
                            <div class="ipsw-inner clearfix" style="font-family: ' . "'$font'" . ';">
                                <div class="ipsw-top">
                                    ' . $html_title . '
                                </div>' . 
                                $html_soc .
                            '</div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Create link popup content
         *
         * @return string
         */
        public function linkPopup()
        {
            if ( ! $this->_widget ) {
                return '';
            }
            $setting    = new IPSocialWidget_Setting( $this->_widgetId );
            $style      = $setting->getSetting( 'style', 'style1' );
            $title      = $setting->getSetting( 'title' );
            $clr_title  = $setting->getSetting( 'title_color' );
            $links      = $setting->getSetting( 'social_links' );
            $font       = $setting->getSetting( 'font_family', 'Arial' );
            $font       = str_replace( '_', ' ', $font );
            
            $html_title = '<h2 class="ipsw-title" style="color: ' . $clr_title . '; font-family: ' . "'$font'" . ';">' . $title . '</h2>';
            
            $html_soc  = '';
            if ( ! empty( $links )) {
                $html_soc = '<div class="ipsw-social">
                                <ul>';
                
                foreach( $links as $link ) {
                    $url = $this->_getSocialHost( $link['type'] ) . $link['url'];
                    $src = plugin_dir_url( dirname(__FILE__) ) . 'img/social/' 
                            . $link['icon'] . '/' . $link['type'] . '.png';
                    $html_soc .= '<li><a href="' . $url . '">
                                    <img src="' . $src . '" alt="' . $link['type'] . '">
                                    <strong>' . $this->_getSocialTitle( $link['type'] ) . '</strong>
                                </a></li>';
                }
                
                $html_soc .= '    </ul>
                            </div>';
            }
            
            $result  = '<div class="ipsw-item ipsw-link ipsw-popup ipsw-' . $style . '">
                            <div class="ipsw-inner clearfix" style="font-family: ' . "'$font'" . ';">
                                <div class="ipsw-top">
                                    ' . $html_title . '
                                </div>' . 
                                $html_soc .
                                '<div class="ipsw-widget-popup-close">
                                    <a href="">x</a>
                                </div>
                            </div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Get social host
         *
         * @return string
         */
        protected function _getSocialHost( $type )
        {
            $host = 'http://';
            if ( $type == 'facebook' ) {
                $host .= 'facebook.com/';
            } elseif ( $type == 'twitter' ) {
                $host .= 'twitter.com/';
            } elseif ( $type == 'linkedin' ) {
                $host .= 'linkedin.com/in/';
            } elseif ( $type == 'pinterest' ) {
                $host .= 'pinterest.com/';
            } elseif ( $type == 'gplus' ) {
                $host .= 'plus.google.com/';
            } elseif ( $type == 'tumblr' ) {
                $host .= '';
            } elseif ( $type == 'youtube' ) {
                $host .= 'youtube.com/user/';
            } elseif ( $type == 'vimeo' ) {
                $host .= 'vimeo.com/';
            } elseif ( $type == 'dribbble' ) {
                $host .= 'dribbble.com/';
            } elseif ( $type == 'instagram' ) {
                $host .= 'instagram.com/';
            } elseif ( $type == 'github' ) {
                $host .= 'github.com/';
            } elseif ( $type == 'flickr' ) {
                $host .= 'flickr.com/photos/';
            }
            return $host;
        }
        
        /**
         * Get social title
         *
         * @return string
         */
        protected function _getSocialTitle( $type )
        {
            $title = '';
            if ( $type == 'facebook' ) {
                $title = 'Facebook';
            } elseif ( $type == 'twitter' ) {
                $title = 'Twitter';
            } elseif ( $type == 'linkedin' ) {
                $title = 'LinkedIn';
            } elseif ( $type == 'pinterest' ) {
                $title = 'Pinterest';
            } elseif ( $type == 'gplus' ) {
                $title = 'Google++';
            } elseif ( $type == 'tumblr' ) {
                $title = 'Tumblr';
            } elseif ( $type == 'youtube' ) {
                $title = 'Youtube';
            } elseif ( $type == 'vimeo' ) {
                $title = 'Vimeo';
            } elseif ( $type == 'dribbble' ) {
                $title = 'Dribbble';
            } elseif ( $type == 'instagram' ) {
                $title = 'Instagram';
            } elseif ( $type == 'github' ) {
                $title = 'Github';
            } elseif ( $type == 'flickr' ) {
                $title = 'Flickr';
            }
            return $title;
        }
    }
}