<?php
if ( ! class_exists( 'IPSocialWidget_ListTable' )) {

    /**
     * Class for display table of  social widget data
     */
    class IPSocialWidget_ListTable extends WP_List_Table
    {
        /**
         * Get a list of columns. The format is:
         * 'internal-name' => 'Title'
         *
         * @return array
         */
        public function get_columns() 
        {
            $posts_columns             = array();
            $posts_columns['name']     = __( 'Name' );
            $posts_columns['type']     = __( 'Type' );
            $posts_columns['style']    = __( 'Style' );
            $posts_columns['modified'] = __( 'Date Modified' );
            $posts_columns['actions']  = __( 'Actions' );
            return $posts_columns;
        }


        /**
         * Get a list of sortable columns. The format is:
         * 'internal-name' => 'orderby'
         * or
         * 'internal-name' => array( 'orderby', true )
         *
         * The second format will make the initial sorting order be descending
         *
         * @return array
         */
        public function get_sortable_columns() 
        {
            return array(
                'name'     => 'name',
                'type'     => 'type',
                'style  '  => 'style',
                'modified' => 'modified',
                'actions'  => 'actions',
            );
        }

        /**
         * Get a list of all, hidden and sortable columns, with filter applied
         *
         * @return array
         */
        public function get_column_info() 
        {
            $columns  = $this->get_columns();
            $hidden   = array();
            $sortable = array();
            $this->_column_headers = array( $columns, $hidden, $sortable );
            return $this->_column_headers;
        }

        /**
         * Prepares the list of items for displaying.
         * @uses WP_List_Table::set_pagination_args()
         *
         */
        public function prepare_items() 
        {
            global $wp_query, $per_page;
            
            $page = 1;
            if ( ! empty( $_GET['paged'] )) {
                $page = absint( $_GET['paged'] );
            }
            $args = array(
                'orderby'     => 'post_date',
                'order'       => 'DESC', 
                'post_type'   => 'ipsocialwidget',
                'post_status' => array(
                    'timeline',
                    'author',
                    'email',
                    'sales',
                    'contact',
                    'profile',
                    'link',
                ),
                'posts_per_page' => 20,
                'paged'          => $page
            );
            $query = new WP_Query;
            $this->items = $query->query( $args );

            $total_items = $query->found_posts;
            $per_page    = $this->get_items_per_page( 'edit_ipsocialwidget_per_page' );
            $per_page    = apply_filters( 'edit_posts_per_page', $per_page, 'ipsocialwidget' );
            $total_pages = ceil( $total_items / $per_page );
            $this->set_pagination_args( array(
                'total_items' => $total_items,
                'total_pages' => $total_pages,
                'per_page' => $per_page
            ) );
        }

        /**
         * Get column name
         *
         * @param object $item
         * @return void
         */
        public function column_name( $item ) 
        {
            $title = $item->post_title;
            $link  = admin_url() . 'admin.php?page=wp-socwidget&action=edit&widget_id='.$item->ID;
            return '<strong><a class="row-title" href="' . $link . '">' . $title . '</a></strong>';
        }

        /**
         * Get column type
         *
         * @param object $item
         * @return void
         */
        public function column_type( $item ) 
        {
            $status = $item->post_status;
            if ( $status == 'timeline' ) {
                $type = __( 'Social Timeline' );
            } elseif ( $status == 'author' ) {
                $type = __( 'Author' );
            } elseif ( $status == 'email' ) {
                $type = __( 'Email Block' );
            } elseif ( $status == 'sales' ) {
                $type = __( 'Sales Block' );
            } elseif ( $status == 'contact' ) {
                $type = __( 'Contact Detail' );
            } elseif ( $status == 'profile' ) {
                $type = __( 'Social Profile' );
            } elseif ( $status == 'link' ) {
                $type = __( 'Social Link' );
            }
            return $type;
        }

        /**
         * Get column style
         *
         * @param object $item
         * @return void
         */
        public function column_style( $item ) 
        {
            $setting = new IPSocialWidget_Setting( $item->ID );
            $style   = $setting->getSetting( 'style' );
            return $style;
        }

        /**
         * Get column modified
         *
         * @param object $item
         * @return void
         */
        public function column_modified( $item ) 
        {
            $format = get_option('date_format') . ' ' . get_option('time_format');
            $date   = mysql2date( $format, $item->post_modified );
            return $date;
        }

        /**
         * Get column actions
         *
         * @param object $item
         * @return void
         */
        public function column_actions( $item ) 
        {
            $linkEdit = admin_url() . 'admin.php?page=wp-socwidget&action=edit&widget_id='.$item->ID;
            $linkDel  = '#toDeleteWidget_'.$item->ID;
            $actions  = '<div class="ip_widgetActions">
                            <a class="ip_widgetEdit button button-primary" href="' . $linkEdit . '">' . __( 'Edit' ) . '</a>
                            <a class="ip_widgetDelete button button-error" href="' . $linkDel . '">' . __( 'Delete' ) . '</a>
                        </div>';
            
            return $actions;
        }

        /**
         * Get column default
         *
         */
        public function column_default() 
        {
            return '';
        }
    }

}
?>