<?php
if ( ! class_exists( 'IPSocialWidget_Setting' )) {

    /**
     * Class for manage widget setting
     */
    class IPSocialWidget_Setting
    {
        /**
         * Take widget id
         *
         * @var string
         */
        protected $_widgetId;
        
        /**
         * Take widget setting
         *
         * @var array
         */
        protected $_settings;
        
        /**
         * Class construct
         *
         * @param int $widgetId
         * @return void
         */
        public function __construct( $widgetId )
        {
            $this->_widgetId = absint( $widgetId );
            $this->_prepare();
        }
        
        /**
         * Get all widget setting
         *
         * @return string
         */
        public function getSettings()
        {
            return $this->_settings;
        }
        
        /**
         * Get widget setting
         *
         * @param  string $key
         * @param  mixed  $default
         * @return string
         */
        public function getSetting( $key, $default = false )
        {
            $setting = $default;
            if ( ! empty( $this->_settings[$key] )) {
                $setting = $this->_settings[$key];
            }
            return $setting;
        }
        
        /**
         * Get all widget setting
         *
         * @param  array $data
         * @return boolean
         */
        public function setSettings( $data )
        {
            $data     = (array)$data;
            $settings = (array)$this->_settings;
            $settings = array_merge( $settings, $data );
            $this->_settings = $settings;
            return $this->_update( $settings );
        }
        
        /**
         * Get widget setting
         *
         * @param  string $key
         * @param  string $value
         * @return boolean
         */
        public function setSetting( $key, $value )
        {
            $data = array(
                $key => $value
            );
            $settings = (array)$this->_settings;
            $settings = array_merge( $settings, $data );
            $this->_settings = $settings;
            return $this->_update( $settings );
        }
        
        /**
         * Reset widget setting
         *
         * @return boolean
         */
        public function reset()
        {
            $data = array( 'ipwidget' => 1 );
            return $this->_update( $data );
        }
        
        /**
         * Prepare class
         *
         * @return void
         */
        protected function _prepare()
        {
            $id    = $this->_widgetId;
            $metas = get_post_meta( $id, '_ip_widget_settings' );
            $meta  = array_shift( $metas );
            $this->_settings = maybe_unserialize( $meta );
        }
        
        /**
         * Update settings
         *
         * @param  array $settings
         * @return boolean
         */
        protected function _update( $settings )
        {
            $settings = (array)$settings;
            return update_post_meta( $this->_widgetId, '_ip_widget_settings', $settings );
        }
    }

}
?>