<?php
if ( ! class_exists( 'IPSocialWidget_Widget' )) {

    /**
     * Class for handling display widget
     */
    class IPSocialWidget_Widget extends WP_Widget
    {
        /**
         * Register widget with WordPress.
         */
        public function __construct() 
        {
            parent::__construct(
                'wp_social_widget', // Base ID
                'WP Social Widget', // Name
                array( 'description' => __( 'A Widget for display social content', 'ipsw_social_widget' ), )
            );
        }

        /**
         * Front-end display of widget.
         *
         * @see WP_Widget::widget()
         *
         * @param array $args     Widget arguments.
         * @param array $instance Saved values from database.
         */
        public function widget( $args, $instance ) 
        {
            $result = '';
            $id     = absint( $instance['widget'] );
            if ( $widget = get_post( $id ) ) {
            
                $type    = $widget->post_status;
                $factory = new IPSocialWidget_Factory( $id );
                if ( $type == 'timeline' ) {
                    $result = $factory->timelineWidget();
                }
                elseif ( $type == 'author' ) {
                    $result = $factory->authorWidget();
                }
                elseif ( $type == 'email' ) {
                    $result = $factory->emailWidget();
                }
                elseif ( $type == 'sales' ) {
                    $result = $factory->salesWidget();
                }
                elseif ( $type == 'profile' ) {
                    $result = $factory->profileWidget();
                }
                elseif ( $type == 'contact' ) {
                    $result = $factory->contactWidget();
                }
                elseif ( $type == 'link' ) {
                    $result = $factory->linkWidget();
                }
            }
            echo $result;
        }

        /**
         * Back-end widget form.
         *
         * @see WP_Widget::form()
         *
         * @param array $instance Previously saved values from database.
         */
        public function form( $instance ) 
        {
            if ( isset( $instance[ 'widget' ] ) ) {
                $widget_id = $instance[ 'widget' ];
            }
            $args = array(
                'orderby'     => 'post_date',
                'order'       => 'DESC', 
                'post_type'   => 'ipsocialwidget',
                'post_status' => array(
                    'timeline',
                    'author',
                    'email',
                    'sales',
                    'contact',
                    'profile',
                    'link',
                ),
                'posts_per_page' => -1,
                'paged'          => $page
            );
            $query   = new WP_Query;
            $widgets = $query->query( $args );
            ?>
            <p>
                <label for="<?php echo $this->get_field_name( 'widget' ); ?>"><?php _e( 'Widget:' ); ?></label> 
                <select id="<?php echo $this->get_field_id( 'widget' ); ?>" name="<?php echo $this->get_field_name( 'widget' ); ?>">
                    <?php
                    foreach( $widgets as $widget ) {
                        
                        $status = $widget->post_status;
                        if ( $status == 'timeline' ) {
                            $type = __( 'Social Timeline' );
                        } elseif ( $status == 'author' ) {
                            $type = __( 'Author' );
                        } elseif ( $status == 'email' ) {
                            $type = __( 'Email Block' );
                        } elseif ( $status == 'sales' ) {
                            $type = __( 'Sales Block' );
                        } elseif ( $status == 'contact' ) {
                            $type = __( 'Contact Detail' );
                        } elseif ( $status == 'profile' ) {
                            $type = __( 'Social Profile' );
                        } elseif ( $status == 'link' ) {
                            $type = __( 'Social Link' );
                        }
                        $selected = '';
                        if ( $widget_id == $widget->ID ) {
                            $selected = ' selected="selected"';
                        }
                        echo '<option' . $selected . ' value="' . $widget->ID .  '">' . $widget->post_title . ' (' . $type . ')</option>';
                    }
                    ?>
                </select>
            </p>
            <?php 
        }

        /**
         * Sanitize widget form values as they are saved.
         *
         * @see WP_Widget::update()
         *
         * @param array $new_instance Values just sent to be saved.
         * @param array $old_instance Previously saved values from database.
         *
         * @return array Updated safe values to be saved.
         */
        public function update( $new_instance, $old_instance ) 
        {
            $instance = array();
            $instance['widget'] = ( ! empty( $new_instance['widget'] ) ) ? absint( $new_instance['widget'] ) : '';

            return $instance;
        }
    }

}
?>