<?php
/*
Plugin Name: WP Social Widget
Plugin URI: 
Description: Plugin that works to create a variety of social content using shortcode and widget
Version: 1.0
Author: InstaPRoduct
Author URI: http://insta-product.com/
*/

/*  
    LICENSE: This source file to be part of a system developed by InstaPRoduct. 
    All copyrights use this file and the code in it owned by InstaPRoduct. 
    It is strictly forbidden to use, copy, modify or distribute this file and 
    the code in it without the permission of the developer.
*/

//Change this value for rebranding plugin
define( 'IPSOCWIDGET_TITLE', 'Social Widget' );

require_once( plugin_dir_path( __FILE__ ) . "includes/setting.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/admin.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/ajax.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/factory.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/widget.php" );

/**
 * Class for generate social content
 */
if ( ! class_exists( 'IPSocialWidget' )) {

    class IPSocialWidget
    {
        /**
         * Setup Plugin
         */
        public function setup()
        {
            //Register admin menu
            add_action( 'admin_menu', array( 'IPSocialWidget', 'addAdminMenu' ) );
            
            //Add Admin style
            add_action( 'admin_print_styles', array( 'IPSocialWidget', 'printAdminStyle' ), 1000 );
            add_action( 'admin_print_footer_scripts', array( 'IPSocialWidget', 'printAdminScript' ), 1000 );
            
            //Ajax handler
            add_action( 'admin_init', array( 'IPSocialWidget', 'doAjax' ) );
            
            // Add generator button to Upload/Insert buttons
            add_action( 'media_buttons', array( 'IPSocialWidget', 'addButton' ), 100 );
            //Add manage pop up content
            add_action( 'admin_footer', array( 'IPSocialWidget', 'managePopup' ) );
            
            //Register Shortcode
            add_shortcode( 'ip_social_widget', array( 'IPSocialWidget', 'shortcode' ) );
            
            //Register Widget
            add_action( 'widgets_init', function(){
                register_widget( 'IPSocialWidget_Widget' );
            });
            
            //Add front style
            add_action('wp_head', array( 'IPSocialWidget', 'printStyle' ) );
            
            //Add front script
            add_action('wp_footer', array( 'IPSocialWidget', 'printScript' ) );
            
            //Add Widget Popup content
            add_action('wp_footer', array( 'IPSocialWidget', 'widgetPopup' ) );
            
            //Add js library
            if ( ! is_admin() ) {
                add_action( "wp_enqueue_scripts", array( 'IPSocialWidget', 'libScript' ), 11 );
            }
        }
        
        /**
         * Add administrator menu
         *
         * @return void
         */
        public function addAdminMenu()
        {
            
            add_menu_page( 
                IPSOCWIDGET_TITLE, 
                IPSOCWIDGET_TITLE, 
                9, 
                'wp-socwidget', 
                array( 'IPSocialWidget', 'adminPage' ), 
                plugin_dir_url( __FILE__ ) . 'img/menu_icon.png'
            );
            add_submenu_page( 
                'wp-socwidget', 
                'All Widget', 
                'All Widget', 
                9, 
                'wp-socwidget',  
                array( 'IPSocialWidget', 'adminPage' )
            );
            add_submenu_page( 
                'wp-socwidget', 
                'Add New', 
                'Add New', 
                9, 
                'wp-socwidget-add', 
                array( 'IPSocialWidget', 'adminAdd' )
            );
            add_submenu_page( 
                'wp-socwidget', 
                'Site Popup', 
                'Site Popup', 
                9, 
                'wp-socwidget-popup', 
                array( 'IPSocialWidget', 'adminPopup' )
            );
        }
        
        /**
         * Processing ajax request
         *
         * @return void
         */
        public function doAjax()
        {
            $ajax = new IPSocialWidget_Ajax();
            return $ajax->exec();
        }
        
        /**
         * Content for administrator page
         *
         * @return void
         */
        public function adminPage()
        {
            $display = new IPSocialWidget_Admin();
            if ( ! empty( $_GET['action'] ) && $_GET['action'] == 'edit' ) {
                $display->edit();
            } else {
                $display->index();
            }
        }
        
        /**
         * Content for administrator page
         *
         * @return void
         */
        public function adminAdd()
        {
            $display = new IPSocialWidget_Admin();
            if ( ! empty( $_GET['type'] )) {
                $display->addType();
            } else {
                $display->add();
            }
        }
        
        /**
         * Content for administrator page
         *
         * @return void
         */
        public function adminPopup()
        {
            $display = new IPSocialWidget_Admin();
            $display->adminPopup();
        }
        
        /**
         * Add button to Upload/Insert buttons
         */
        public function addButton( $page = null, $target = null ) 
        {
            $href  = '#TB_inline?width=640&height=400&inlineId=ipsw-shortcode-popup';
            $title = __( 'Insert Social Widget', 'wp-social-widget' );
            
            echo '<a href="' . $href . '" class="thickbox button ipsw-button" title="' . $title . '" data-page="' . $page . '" data-target="' . $target . '">
                    <span class="ipsw-button-icon"></span>
                </a>';
        }
        
        /**
         * Create manage pop up content
         */
        public function managePopup() 
        {
            $display = new IPSocialWidget_Admin();
            $display->popup();
        }
        
        /**
         * Insert shortcode
         */
        public function shortcode( $atts, $content = '') 
        {
            $result = $content;
            if ( ! empty( $atts['type'] ) && ! empty( $atts['id'] )) {
            
                $id      = absint( $atts['id'] );
                $type    = trim( $atts['type'] );
                $factory = new IPSocialWidget_Factory( $id );
                if ( $type == 'timeline' ) {
                    $result = $factory->timelinePost();
                }
                elseif ( $type == 'author' ) {
                    $result = $factory->authorPost();
                }
                elseif ( $type == 'email' ) {
                    $result = $factory->emailPost();
                }
                elseif ( $type == 'sales' ) {
                    $result = $factory->salesPost();
                }
                elseif ( $type == 'profile' ) {
                    $result = $factory->profilePost();
                }
                elseif ( $type == 'contact' ) {
                    $result = $factory->contactPost();
                }
                elseif ( $type == 'link' ) {
                    $result = $factory->linkPost();
                }
            }
            return $result;
        }
        
        /**
         * Insert widget popup
         */
        public function widgetPopup() 
        {
            $widget_id = get_option( '_ipsw_site_popup' );
            if ( empty( $widget_id )) {
                return '';
            }
            $widget_id = absint( $widget_id );
            if ( ! $widget = get_post( $widget_id ) ) {
                return '';
            }
            $width   = get_option( '_ipsw_site_popup_width', 500 );
            $result  = '<div id="ipsw-site-widget-popup" style="width:' . $width . 'px;">';
            $type    = $widget->post_status;
            $factory = new IPSocialWidget_Factory( $widget );
            if ( $type == 'timeline' ) {
                $result .= $factory->timelinePopup();
            }
            elseif ( $type == 'author' ) {
                $result .= $factory->authorPopup();
            }
            elseif ( $type == 'email' ) {
                $result .= $factory->emailPopup();
            }
            elseif ( $type == 'sales' ) {
                $result .= $factory->salesPopup();
            }
            elseif ( $type == 'profile' ) {
                $result .= $factory->profilePopup();
            }
            elseif ( $type == 'contact' ) {
                $result .= $factory->contactPopup();
            }
            elseif ( $type == 'link' ) {
                $result .= $factory->linkPopup();
            }
            $result .= '</div>';
            echo $result;
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public function printAdminStyle()
        {
            $href1 = plugin_dir_url( __FILE__ ) . 'css/admin.css';
            $href2 = plugin_dir_url( __FILE__ ) . 'css/widget.css';
            echo '<link media="all" type="text/css" href="' . $href1 . '" rel="stylesheet">';
            echo '<link media="all" type="text/css" href="' . $href2 . '" rel="stylesheet">';
        }

        /**
         * Print Admin Script
         *
         * @return void
         */
        public function printAdminScript()
        {
            $src1 = plugin_dir_url( __FILE__ ) . 'js/admin.js';
            $src2 = plugin_dir_url( __FILE__ ) . 'js/spin.min.js';
            echo '<script type="text/javascript" src="' . $src1 . '"></script>';
            echo '<script type="text/javascript" src="' . $src2 . '"></script>';
        }

        /**
         * Print style
         *
         * @return void
         */
        public function printStyle()
        {
        ?>
            <link media="all" type="text/css" href="<?php echo plugin_dir_url( __FILE__ ) ?>css/widget.css" rel="stylesheet">
        <?php
        }

        /**
         * Print script
         *
         * @return void
         */
        public function printScript()
        {
            $src = plugin_dir_url( __FILE__ ) . 'js/script.js';
            echo '<script type="text/javascript" src="' . $src . '"></script>';
        }

        /**
         * Lib script
         *
         * @return void
         */
        public function libScript()
        {
            wp_deregister_script('jquery');
            wp_register_script('jquery', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jquery/1.7.1/jquery.min.js", false, null);
            wp_enqueue_script('jquery');
            
            wp_deregister_script('jquery-ui');
            wp_register_script('jquery-ui', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jqueryui/1.10.3/jquery-ui.min.js", false, null);
            wp_enqueue_script('jquery-ui');
        }
    }

}
//Run plugin
IPSocialWidget::setup();
?>